@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_ACCESS_USER_H
-#define INCLUDED_ACCESS_USER_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+namespace access_user {
 
-vector <string> access_user_assignees (void * webserver_request);
+std::vector <std::string> assignees (void * webserver_request);
 
-
-#endif
+}
