@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CHANGES_CHANGES_H
-#define INCLUDED_CHANGES_CHANGES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string changes_changes_url ();
+std::string changes_changes_url ();
 bool changes_changes_acl (void * webserver_request);
-string changes_changes (void * webserver_request);
-
-
-#endif
+std::string changes_changes (void * webserver_request);
