@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -19,20 +19,23 @@
 
 #include <checks/logic.h>
 #include <database/bibles.h>
+#include <database/config/bible.h>
 #include <tasks/logic.h>
+using namespace std;
 
 
 void checks_logic_start_all ()
 {
-  Database_Bibles database_bibles;
-  vector <string> bibles = database_bibles.getBibles ();
-  for (auto bible : bibles) {
-    checks_logic_start (bible);
+  Database_Bibles database_bibles {};
+  const vector <string> & bibles = database_bibles.getBibles ();
+  for (const auto & bible : bibles) {
+    bool enabled = Database_Config_Bible::getDailyChecksEnabled (bible);
+    if (enabled) checks_logic_start (bible);
   }
 }
 
 
-void checks_logic_start (string bible)
+void checks_logic_start (const string & bible)
 {
   tasks_logic_queue (CHECKBIBLE, {bible});
 }
