@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,15 +17,9 @@
  */
 
 
-#ifndef INCLUDED_CHECKS_LOGIC_H
-#define INCLUDED_CHECKS_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void checks_logic_start_all ();
-void checks_logic_start (string bible);
-
-
-#endif
+void checks_logic_start (const std::string & bible);
