@@ -23,11 +23,11 @@
 
 namespace checks::space {
 
-void double_space_usfm (string bible, int book, int chapter, int verse, string data);
-void space_before_punctuation (string bible, int book, int chapter, map <int, string> texts);
-void space_end_verse (string bible, int book, int chapter, string usfm);
-bool transpose_note_space (string & usfm);
-void space_before_final_note_markup (string bible, int book, int chapter, int verse, string data);
+void double_space_usfm (const std::string & bible, int book, int chapter, int verse, const std::string & data);
+void space_before_punctuation (const std::string & bible, int book, int chapter, const std::map <int, std::string> & texts);
+void space_end_verse (const std::string & bible, int book, int chapter, const std::string & usfm);
+bool transpose_note_space (std::string & usfm);
+void space_before_final_note_markup (const std::string & bible, int book, int chapter, int verse, const std::string & data);
 
 }
 
