@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string client_index_url ();
+std::string client_index_url ();
 bool client_index_acl (void * webserver_request);
-string client_index (void * webserver_request);
+std::string client_index (void * webserver_request);
