@@ -31,6 +31,7 @@
 #include <database/config/bible.h>
 #include <database/config/general.h>
 #include <database/jobs.h>
+using namespace std;
 
 
 void collaboration_link ([[maybe_unused]] string object,
@@ -70,6 +71,7 @@ void collaboration_link ([[maybe_unused]] string object,
     if (!takeme && !takerepo) {
       error = translate ("It is unclear which data to copy to where");
       result = false;
+      if (result) {};
     }
   }
 
@@ -272,7 +274,7 @@ void collaboration_link ([[maybe_unused]] string object,
   view.set_variable ("success", filter_string_implode (success, "<br>\n"));
   view.set_variable ("error", error);
   page += view.render ("collaboration", "link");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   database_jobs.set_result (jobid, page);
 #endif
 }
