@@ -36,6 +36,7 @@
 #include <database/books.h>
 #include <database/config/bible.h>
 #include <jobs/index.h>
+using namespace std;
 
 
 void compare_compare (string bible, string compare, int jobId)
@@ -90,7 +91,7 @@ void compare_compare (string bible, string compare, int jobId)
   for (auto & book : books) {
 
     
-    string bookName = Database_Books::getEnglishFromId (book);
+    string bookName = database::books::get_english_from_id (static_cast<book_id>(book));
     database_jobs.set_progress (jobId, bookName);
     
     
