@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_CONSISTENCY_INPUT_H
-#define INCLUDED_CONSISTENCY_INPUT_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string consistency_input_url ();
+std::string consistency_input_url ();
 bool consistency_input_acl (void * webserver_request);
-string consistency_input (void * webserver_request);
-
-
-#endif
+std::string consistency_input (void * webserver_request);
