@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string consistency_poll_url ();
+std::string consistency_poll_url ();
 bool consistency_poll_acl (void * webserver_request);
-string consistency_poll (void * webserver_request);
+std::string consistency_poll (void * webserver_request);
