@@ -27,26 +27,26 @@ class Database_Config_User
 public:
   Database_Config_User (void * webserver_request_in);
   void trim ();
-  void remove (string username);
+  void remove (std::string username);
   void clear_cache ();
-  string getBible ();
-  void setBible (string bible);
+  std::string getBible ();
+  void setBible (std::string bible);
   bool getSubscribeToConsultationNotesEditedByMe ();
   void setSubscribeToConsultationNotesEditedByMe (bool value);
   bool getNotifyMeOfAnyConsultationNotesEdits ();
-  bool getNotifyUserOfAnyConsultationNotesEdits (string username);
+  bool getNotifyUserOfAnyConsultationNotesEdits (std::string username);
   void setNotifyMeOfAnyConsultationNotesEdits (bool value);
   bool getSubscribedConsultationNoteNotification ();
-  bool getUserSubscribedConsultationNoteNotification (string username);
+  bool getUserSubscribedConsultationNoteNotification (std::string username);
   void setSubscribedConsultationNoteNotification (bool value);
   bool getAssignedToConsultationNotesChanges ();
-  bool getUserAssignedToConsultationNotesChanges (string username);
+  bool getUserAssignedToConsultationNotesChanges (std::string username);
   void setAssignedToConsultationNotesChanges (bool value);
   bool getGenerateChangeNotifications ();
-  bool getUserGenerateChangeNotifications (string username);
+  bool getUserGenerateChangeNotifications (std::string username);
   void setGenerateChangeNotifications (bool value);
   bool getAssignedConsultationNoteNotification ();
-  bool getUserAssignedConsultationNoteNotification (string username);
+  bool getUserAssignedConsultationNoteNotification (std::string username);
   void setAssignedConsultationNoteNotification (bool value);
   int getConsultationNotesPassageSelector ();
   void setConsultationNotesPassageSelector (int value);
@@ -54,90 +54,90 @@ public:
   void setConsultationNotesEditSelector (int value);
   int getConsultationNotesNonEditSelector ();
   void setConsultationNotesNonEditSelector (int value);
-  string getConsultationNotesStatusSelector ();
-  void setConsultationNotesStatusSelector (string value);
-  string getConsultationNotesBibleSelector ();
-  void setConsultationNotesBibleSelector (string value);
-  string getConsultationNotesAssignmentSelector ();
-  void setConsultationNotesAssignmentSelector (string value);
+  std::string getConsultationNotesStatusSelector ();
+  void setConsultationNotesStatusSelector (std::string value);
+  std::string getConsultationNotesBibleSelector ();
+  void setConsultationNotesBibleSelector (std::string value);
+  std::string getConsultationNotesAssignmentSelector ();
+  void setConsultationNotesAssignmentSelector (std::string value);
   bool getConsultationNotesSubscriptionSelector ();
   void setConsultationNotesSubscriptionSelector (bool value);
   int getConsultationNotesSeveritySelector ();
   void setConsultationNotesSeveritySelector (int value);
   int getConsultationNotesTextSelector ();
   void setConsultationNotesTextSelector (int value);
-  string getConsultationNotesSearchText ();
-  void setConsultationNotesSearchText (string value);
+  std::string getConsultationNotesSearchText ();
+  void setConsultationNotesSearchText (std::string value);
   int getConsultationNotesPassageInclusionSelector ();
   void setConsultationNotesPassageInclusionSelector (int value);
   int getConsultationNotesTextInclusionSelector ();
   void setConsultationNotesTextInclusionSelector (int value);
   bool getBibleChangesNotification ();
-  bool getUserBibleChangesNotification (string username);
+  bool getUserBibleChangesNotification (std::string username);
   void setBibleChangesNotification (bool value);
   bool getDeletedConsultationNoteNotification ();
-  bool getUserDeletedConsultationNoteNotification (string username);
+  bool getUserDeletedConsultationNoteNotification (std::string username);
   void setDeletedConsultationNoteNotification (bool value);
   bool getBibleChecksNotification ();
-  bool getUserBibleChecksNotification (string username);
+  bool getUserBibleChecksNotification (std::string username);
   void setBibleChecksNotification (bool value);
   bool getPendingChangesNotification ();
-  bool getUserPendingChangesNotification (string username);
+  bool getUserPendingChangesNotification (std::string username);
   void setPendingChangesNotification (bool value);
   bool getUserChangesNotification ();
-  bool getUserUserChangesNotification (string username);
+  bool getUserUserChangesNotification (std::string username);
   void setUserChangesNotification (bool value);
   bool getAssignedNotesStatisticsNotification ();
-  bool getUserAssignedNotesStatisticsNotification (string username);
+  bool getUserAssignedNotesStatisticsNotification (std::string username);
   void setAssignedNotesStatisticsNotification (bool value);
   bool getSubscribedNotesStatisticsNotification ();
-  bool getUserSubscribedNotesStatisticsNotification (string username);
+  bool getUserSubscribedNotesStatisticsNotification (std::string username);
   void setSubscribedNotesStatisticsNotification (bool value);
   bool getNotifyMeOfMyPosts ();
-  bool getUserNotifyMeOfMyPosts (string username);
+  bool getUserNotifyMeOfMyPosts (std::string username);
   void setNotifyMeOfMyPosts (bool value);
   bool getSuppressMailFromYourUpdatesNotes ();
-  bool getUserSuppressMailFromYourUpdatesNotes (string username);
+  bool getUserSuppressMailFromYourUpdatesNotes (std::string username);
   void setSuppressMailFromYourUpdatesNotes (bool value);
-  vector <string> getActiveResources ();
-  void setActiveResources (vector <string> values);
-  vector <string> getConsistencyResources ();
-  void setConsistencyResources (vector <string> values);
+  std::vector <std::string> getActiveResources ();
+  void setActiveResources (std::vector <std::string> values);
+  std::vector <std::string> getConsistencyResources ();
+  void setConsistencyResources (std::vector <std::string> values);
   int getSprintMonth ();
   void setSprintMonth (int value);
   int getSprintYear ();
   void setSprintYear (int value);
   bool getSprintProgressNotification ();
-  bool getUserSprintProgressNotification (string username);
+  bool getUserSprintProgressNotification (std::string username);
   void setSprintProgressNotification (bool value);
   bool getUserChangesNotificationsOnline ();
-  bool getUserUserChangesNotificationsOnline (string username);
+  bool getUserUserChangesNotificationsOnline (std::string username);
   void setUserChangesNotificationsOnline (bool value);
   bool getContributorChangesNotificationsOnline ();
-  bool getContributorChangesNotificationsOnline (string username);
+  bool getContributorChangesNotificationsOnline (std::string username);
   void setContributorChangesNotificationsOnline (bool value);
-  string getWorkspaceURLs ();
-  void setWorkspaceURLs (string value);
-  string getWorkspaceWidths ();
-  void setWorkspaceWidths (string value);
-  string getWorkspaceHeights ();
-  void setWorkspaceHeights (string value);
-  string getEntireWorkspaceWidths ();
-  void setEntireWorkspaceWidths (string value);
-  string getActiveWorkspace ();
-  void setActiveWorkspace (string value);
+  std::string getWorkspaceURLs ();
+  void setWorkspaceURLs (std::string value);
+  std::string getWorkspaceWidths ();
+  void setWorkspaceWidths (std::string value);
+  std::string getWorkspaceHeights ();
+  void setWorkspaceHeights (std::string value);
+  std::string getEntireWorkspaceWidths ();
+  void setEntireWorkspaceWidths (std::string value);
+  std::string getActiveWorkspace ();
+  void setActiveWorkspace (std::string value);
   bool getPostponeNewNotesMails ();
   void setPostponeNewNotesMails (bool value);
-  string getRecentlyAppliedStyles ();
-  void setRecentlyAppliedStyles (string values);
-  vector <string> getPrintResources ();
-  vector <string> getPrintResourcesForUser (string user);
-  void setPrintResources (vector <string> values);
+  std::string getRecentlyAppliedStyles ();
+  void setRecentlyAppliedStyles (std::string values);
+  std::vector <std::string> getPrintResources ();
+  std::vector <std::string> getPrintResourcesForUser (std::string user);
+  void setPrintResources (std::vector <std::string> values);
   Passage getPrintPassageFrom ();
-  Passage getPrintPassageFromForUser (string user);
+  Passage getPrintPassageFromForUser (std::string user);
   void setPrintPassageFrom (Passage value);
   Passage getPrintPassageTo ();
-  Passage getPrintPassageToForUser (string user);
+  Passage getPrintPassageToForUser (std::string user);
   void setPrintPassageTo (Passage value);
   int getFocusedBook ();
   void setFocusedBook (int book);
@@ -145,27 +145,27 @@ public:
   void setFocusedChapter (int chapter);
   int getFocusedVerse ();
   void setFocusedVerse (int verse);
-  vector <int> getUpdatedSettings ();
-  void setUpdatedSettings (vector <int> values);
+  std::vector <int> getUpdatedSettings ();
+  void setUpdatedSettings (std::vector <int> values);
   void addUpdatedSetting (int value);
   void removeUpdatedSetting (int value);
-  vector <int> getRemovedChanges ();
-  void setRemovedChanges (vector <int> values);
+  std::vector <int> getRemovedChanges ();
+  void setRemovedChanges (std::vector <int> values);
   void addRemovedChange (int value);
   void removeRemovedChange (int value);
-  string getChangeNotificationsChecksum ();
-  void setChangeNotificationsChecksum (string value);
-  void setUserChangeNotificationsChecksum (string user, string value);
+  std::string getChangeNotificationsChecksum ();
+  void setChangeNotificationsChecksum (std::string value);
+  void setUserChangeNotificationsChecksum (std::string user, std::string value);
   void setLiveBibleEditor (int time);
   int getLiveBibleEditor ();
   void setResourceVersesBefore (int verses);
   int getResourceVersesBefore ();
   void setResourceVersesAfter (int verses);
   int getResourceVersesAfter ();
-  string getSyncKey ();
-  void setSyncKey (string key);
-//  string getSiteLanguage ();
-//  void setSiteLanguage (string value);
+  std::string getSyncKey ();
+  void setSyncKey (std::string key);
+//  std::string getSiteLanguage ();
+//  void setSiteLanguage (std::string value);
   void setGeneralFontSize (int size);
   int getGeneralFontSize ();
   void setMenuFontSize (int size);
@@ -210,12 +210,12 @@ public:
   bool getMenuChangesInBasicMode ();
   void setMenuChangesInBasicMode (bool value);
   bool getPrivilegeUseAdvancedMode ();
-  bool getPrivilegeUseAdvancedModeForUser (string username);
-  void setPrivilegeUseAdvancedModeForUser (string username, bool value);
+  bool getPrivilegeUseAdvancedModeForUser (std::string username);
+  void setPrivilegeUseAdvancedModeForUser (std::string username, bool value);
   bool getPrivilegeDeleteConsultationNotes ();
   void setPrivilegeDeleteConsultationNotes (bool value);
-  bool getPrivilegeDeleteConsultationNotesForUser (string username);
-  void setPrivilegeDeleteConsultationNotesForUser (string username, bool value);
+  bool getPrivilegeDeleteConsultationNotesForUser (std::string username);
+  void setPrivilegeDeleteConsultationNotesForUser (std::string username, bool value);
   bool getDismissChangesAtTop ();
   void setDismissChangesAtTop (bool value);
   bool getQuickNoteEditLink ();
@@ -228,8 +228,8 @@ public:
   void setShowVerseTextAtCreateNote (bool value);
   bool getOrderChangesByAuthor ();
   void setOrderChangesByAuthor (bool value);
-  vector <string> getAutomaticNoteAssignment ();
-  void setAutomaticNoteAssignment (vector <string> values);
+  std::vector <std::string> getAutomaticNoteAssignment ();
+  void setAutomaticNoteAssignment (std::vector <std::string> values);
   bool getReceiveFocusedReferenceFromParatext ();
   void setReceiveFocusedReferenceFromParatext (bool value);
   bool getReceiveFocusedReferenceFromAccordance ();
@@ -238,31 +238,31 @@ public:
   void setUseColoredNoteStatusLabels (bool value);
   int getNotesDateFormat ();
   void setNotesDateFormat (int value);
-  vector <string> getChangeNotificationsBibles ();
-  vector <string> getChangeNotificationsBiblesForUser (const string & user);
-  void setChangeNotificationsBibles (const vector <string>& values);
+  std::vector <std::string> getChangeNotificationsBibles ();
+  std::vector <std::string> getChangeNotificationsBiblesForUser (const std::string & user);
+  void setChangeNotificationsBibles (const std::vector <std::string>& values);
 private:
   void * webserver_request {nullptr};
-  string file (string user);
-  string file (string user, const char * key);
-  string mapkey (string user, const char * key);
-  string getValue (const char * key, const char * default_value);
+  std::string file (std::string user);
+  std::string file (std::string user, const char * key);
+  std::string mapkey (std::string user, const char * key);
+  std::string getValue (const char * key, const char * default_value);
   bool getBValue (const char * key, bool default_value);
   int getIValue (const char * key, int default_value);
-  string getValueForUser (string user, const char * key, const char * default_value);
-  bool getBValueForUser (string user, const char * key, bool default_value);
-  int getIValueForUser (string user, const char * key, int default_value);
-  void setValue (const char * key, string value);
+  std::string getValueForUser (std::string user, const char * key, const char * default_value);
+  bool getBValueForUser (std::string user, const char * key, bool default_value);
+  int getIValueForUser (std::string user, const char * key, int default_value);
+  void setValue (const char * key, std::string value);
   void setBValue (const char * key, bool value);
   void setIValue (const char * key, int value);
-  void setValueForUser (string user, const char * key, string value);
-  void setBValueForUser (string user, const char * key, bool value);
-  vector <string> getList (const char * key);
-  vector <string> getListForUser (string user, const char * key);
-  void setList (const char * key, vector <string> values);
-  void setListForUser (string user, const char * key, vector <string> values);
-  vector <int> getIList (const char * key);
-  void setIList (const char * key, vector <int> values);
+  void setValueForUser (std::string user, const char * key, std::string value);
+  void setBValueForUser (std::string user, const char * key, bool value);
+  std::vector <std::string> getList (const char * key);
+  std::vector <std::string> getListForUser (std::string user, const char * key);
+  void setList (const char * key, std::vector <std::string> values);
+  void setListForUser (std::string user, const char * key, std::vector <std::string> values);
+  std::vector <int> getIList (const char * key);
+  void setIList (const char * key, std::vector <int> values);
   const char * keySprintMonth ();
   const char * keySprintYear ();
   bool defaultBibleChecksNotification ();
