@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,37 +17,31 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_IMAGERESOURCES_H
-#define INCLUDED_DATABASE_IMAGERESOURCES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_ImageResources
 {
 public:
-  vector <string> names ();
-  void create (string name);
-  void erase (string name);
-  void erase (string name, string image);
-  string store (string name, string file);
-  void assign (string name, string image,
+  std::vector <std::string> names ();
+  void create (std::string name);
+  void erase (std::string name);
+  void erase (std::string name, std::string image);
+  std::string store (std::string name, std::string file);
+  void assign (std::string name, std::string image,
                int book1, int chapter1, int verse1,
                int book2, int chapter2, int verse2);
-  vector <string> get (string name, int book, int chapter, int verse);
-  vector <string> get (string name);
-  void get (string name, string image,
+  std::vector <std::string> get (std::string name, int book, int chapter, int verse);
+  std::vector <std::string> get (std::string name);
+  void get (std::string name, std::string image,
             int & book1, int & chapter1, int & verse1,
             int & book2, int & chapter2, int & verse2);
-  string get (string name, string image);
+  std::string get (std::string name, std::string image);
 private:
-  string mainFolder ();
-  string resourceFolder (const string& name);
-  string imagePath (string name, string image);
-  string databaseFile ();
-  sqlite3 * connect (string name);
+  std::string mainFolder ();
+  std::string resourceFolder (const std::string& name);
+  std::string imagePath (std::string name, std::string image);
+  std::string databaseFile ();
+  sqlite3 * connect (std::string name);
 };
-
-
-#endif
