@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/md5.h>
 #include <filter/roles.h>
 #include <filter/date.h>
+using namespace std;
 
 
 // This database is resilient.
@@ -214,5 +215,5 @@ void Database_Login::testTimestamp ()
 // Gets the current number of days since the Unix epoch.
 int Database_Login::timestamp ()
 {
-  return filter_date_seconds_since_epoch () / 86400;
+  return filter::date::seconds_since_epoch () / 86400;
 }
