@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,13 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_LOGIN_H
-#define INCLUDED_DATABASE_LOGIN_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_Login
 {
 public:
@@ -32,16 +29,13 @@ public:
   static void trim ();
   static void optimize ();
   static bool healthy ();
-  static void setTokens (string username, string address, string agent, string fingerprint, string cookie, bool touch);
-  static void removeTokens (string username);
-  static void removeTokens (string username, string cookie);
-  static void renameTokens (string username_existing, string username_new, string cookie);
-  static string getUsername (string cookie, bool & daily);
-  static bool getTouchEnabled (string cookie);
+  static void setTokens (std::string username, std::string address, std::string agent, std::string fingerprint, std::string cookie, bool touch);
+  static void removeTokens (std::string username);
+  static void removeTokens (std::string username, std::string cookie);
+  static void renameTokens (std::string username_existing, std::string username_new, std::string cookie);
+  static std::string getUsername (std::string cookie, bool & daily);
+  static bool getTouchEnabled (std::string cookie);
   static void testTimestamp ();
 private:
   static int timestamp ();
 };
-
-
-#endif
