@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,30 +17,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_MORPHOLOGY_H
-#define INCLUDED_DATABASE_MORPHOLOGY_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 class Database_MorphGnt
 {
 public:
   void create ();
   void optimize ();
   void store (int book, int chapter, int verse,
-              string pos, string parsing, string word, string lemma);
-  vector <int> rowids (int book, int chapter, int verse);
-  string pos (int rowid);
-  string parsing (int rowid);
-  string word (int rowid);
-  string lemma (int rowid);
+              std::string pos, std::string parsing, std::string word, std::string lemma);
+  std::vector <int> rowids (int book, int chapter, int verse);
+  std::string pos (int rowid);
+  std::string parsing (int rowid);
+  std::string word (int rowid);
+  std::string lemma (int rowid);
 private:
   const char * filename ();
-  int get_id (const char * table_row, string item);
-  string get_item (const char * item, int rowid);
+  int get_id (const char * table_row, std::string item);
+  std::string get_item (const char * item, int rowid);
 };
 
-
-#endif
