@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,17 +17,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_DATABASE_SPRINT_H
-#define INCLUDED_DATABASE_SPRINT_H
-
+#pragma once
 
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-
 #ifdef HAVE_CLOUD
 
-
 class Database_Sprint_Item
 {
 public:
@@ -36,28 +32,23 @@ public:
   int complete;
 };
 
-
 class Database_Sprint
 {
 public:
   void create ();
   void optimize ();
-  void storeTask (const string& bible, int year, int month, const string& title);
+  void storeTask (const std::string& bible, int year, int month, const std::string& title);
   void deleteTask (int id);
-  vector <int> getTasks (const string& bible, int year, int month);
-  string getTitle (int id);
+  std::vector <int> getTasks (const std::string& bible, int year, int month);
+  std::string getTitle (int id);
   void updateComplete (int id, int percentage);
   int getComplete (int id);
   void updateMonthYear (int id, int month, int year);
-  void logHistory (const string& bible, int year, int month, int day, int tasks, int complete);
-  vector <Database_Sprint_Item> getHistory (const string& bible, int year, int month);
-  void clearHistory (const string& bible, int year, int month);
+  void logHistory (const std::string& bible, int year, int month, int day, int tasks, int complete);
+  std::vector <Database_Sprint_Item> getHistory (const std::string& bible, int year, int month);
+  void clearHistory (const std::string& bible, int year, int month);
 private:
   sqlite3 * connect ();
 };
 
-
-#endif
-
-
 #endif
