@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/string.h>
 #include <database/sqlite.h>
+using namespace std;
 
 
 // Database resilience: It is stored in the plain filesystem in the temporal location.
@@ -42,5 +43,6 @@ string Database_Volatile::filename (int id, string key)
 {
   string identifier = filter_url_clean_filename (convert_to_string (id));
   key = filter_url_clean_filename (key);
-  return filter_url_create_root_path (filter_url_temp_dir (), "volatile__" + identifier + "__" + key);
+  string path = filter_url_create_root_path ({filter_url_temp_dir (), "volatile__" + identifier + "__" + key});
+  return path;
 }
