@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,27 +17,26 @@
  */
 
 
-#ifndef INCLUDED_DEMO_LOGIC_H
-#define INCLUDED_DEMO_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+bool demo_acl (std::string user, std::string pass);
 
-bool demo_acl (string user, string pass);
-string demo_address ();
-string demo_address_secure ();
-int demo_port ();
-int demo_port_secure ();
-string demo_client_warning ();
+// Returns the address of the current demo server.
+constexpr std::string_view demo_address () {return "http://bibledit.org";}
+constexpr std::string_view demo_address_secure () {return "https://bibledit.org";}
+
+// The port number of the current demo server.
+constexpr int demo_port () {return 8090;}
+constexpr int demo_port_secure () {return 8091;}
+
+std::string demo_client_warning ();
 void demo_clean_data ();
-string demo_sample_bible_name ();
+std::string demo_sample_bible_name ();
 void demo_create_sample_bible ();
 void demo_prepare_sample_bible ();
 void demo_create_sample_notes (void * webserver_request);
-string demo_workspace ();
+std::string demo_workspace ();
 void demo_create_sample_workspaces (void * webserver_request);
-vector <string> demo_logic_default_resources ();
-
-
-#endif
+std::vector <std::string> demo_logic_default_resources ();
