@@ -24,16 +24,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 class Dialog_List
 {
 public:
-  Dialog_List (string url, string question, string info_top, string info_bottom, bool post = false);
+  Dialog_List (std::string url, std::string question, std::string info_top, std::string info_bottom, bool post = false);
   ~Dialog_List ();
   Dialog_List(const Dialog_List&) = delete;
   Dialog_List operator=(const Dialog_List&) = delete;
-  void add_query (string parameter, string value);
-  void add_row (string text, string parameter, string value);
-  string run ();
+  void add_query (std::string parameter, std::string value);
+  void add_row (std::string text, std::string parameter, std::string value);
+  std::string run ();
 private:
   void * assets_view {nullptr};
-  string base_url {};
-  string list_block {};
+  std::string base_url {};
+  std::string list_block {};
   bool post_result {false};
 };
