@@ -30,6 +30,7 @@
 #include <locale/translate.h>
 #include <assets/view.h>
 #include <access/bible.h>
+using namespace std;
 
 
 string edit_edit_url ()
@@ -41,7 +42,7 @@ string edit_edit_url ()
 bool edit_edit_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [read, write] = AccessBible::Any (webserver_request);
+  auto [read, write] = access_bible::any (webserver_request);
   return read;
 }
 
