@@ -21,5 +21,5 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-void storeLoadedUsfm2 (void * webserver_request, string bible, int book, int chapter, string editor, const char * message = "");
-string getLoadedUsfm2 (void * webserver_request, string bible, int book, int chapter, string editor);
+void storeLoadedUsfm2 (void * webserver_request, std::string bible, int book, int chapter, std::string editor, const char * message = "");
+std::string getLoadedUsfm2 (void * webserver_request, std::string bible, int book, int chapter, std::string editor);
