@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string edit_navigate_url ();
+std::string edit_navigate_url ();
 bool edit_navigate_acl (void * webserver_request);
-string edit_navigate (void * webserver_request);
+std::string edit_navigate (void * webserver_request);
