@@ -24,6 +24,13 @@ var verseEditorUniqueID = Math.floor (Math.random() * 100000000);
 
 $ (document).ready (function ()
 {
+  // Listens for bibleselect option tags value change to update the loaded Bible.
+  var bibleSelectionElement = document.querySelector ("#bibleselect");
+  bibleSelectionElement.addEventListener ('change', () => {
+    $.post ("index", { bibleselect: bibleSelectionElement.value })
+      .done (function() { window.location.reload () });
+  });
+
   // Make the editor's menu to never scroll out of view.
   var bar = $ ("#editorheader").remove ();
   $ ("#workspacemenu").append (bar);
