@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,18 +17,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_EDITONE2_LOGIC_H
-#define INCLUDED_EDITONE2_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-void editone2_logic_prefix_html (string usfm, string stylesheet, string & html, string & last_p_style);
-void editone2_logic_editable_html (string usfm, string stylesheet, string & html);
-void editone2_logic_suffix_html (string editable_last_p_style, string usfm, string stylesheet, string & html);
-string editone2_logic_html_to_usfm (string stylesheet, string html);
-void editone2_logic_move_notes (string & prefix, string & suffix);
-
-
-#endif
+void editone_logic_prefix_html (std::string usfm, std::string stylesheet, std::string & html, std::string & last_p_style);
+void editone_logic_editable_html (std::string usfm, std::string stylesheet, std::string & html);
+void editone_logic_suffix_html (std::string editable_last_p_style, std::string usfm, std::string stylesheet, std::string & html);
+std::string editone_logic_html_to_usfm (std::string stylesheet, std::string html);
+void editone_logic_move_notes_v2 (std::string & prefix, std::string & suffix);
