@@ -26,6 +26,7 @@
 #include <ipc/focus.h>
 #include <database/ipc.h>
 #include <access/bible.h>
+using namespace std;
 
 
 string editor_id_url ()
@@ -37,7 +38,7 @@ string editor_id_url ()
 bool editor_id_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
