@@ -37,6 +37,7 @@
 #include <menu/logic.h>
 #include <bb/logic.h>
 #include <workspace/logic.h>
+using namespace std;
 
 
 string editusfm_index_url ()
@@ -48,7 +49,7 @@ string editusfm_index_url ()
 bool editusfm_index_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
@@ -82,10 +83,10 @@ string editusfm_index (void * webserver_request)
   string page;
   
   Assets_Header header = Assets_Header (translate("Edit USFM"), request);
-  header.setNavigator ();
-  header.addBreadCrumb (menu_logic_translate_menu (), menu_logic_translate_text ());
-  if (touch) header.jQueryTouchOn ();
-  header.notifItOn ();
+  header.set_navigator ();
+  header.add_bread_crumb (menu_logic_translate_menu (), menu_logic_translate_text ());
+  if (touch) header.jquery_touch_on ();
+  header.notify_it_on ();
   page = header.run ();
   Assets_View view;
 
@@ -94,10 +95,10 @@ string editusfm_index (void * webserver_request)
   // Or if the user have used query to preset the active Bible, get the preset Bible.
   // If needed, change Bible to one it has read access to.
   // Set the chosen Bible on the option HTML tag.
-  string bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
-  if (request->query.count ("bible")) bible = AccessBible::Clamp (request, request->query ["bible"]);
+  string bible = access_bible::clamp (request, request->database_config_user()->getBible ());
+  if (request->query.count ("bible")) bible = access_bible::clamp (request, request->query ["bible"]);
   string bible_html;
-  vector <string> bibles = AccessBible::Bibles (request);
+  vector <string> bibles = access_bible::bibles (request);
   for (auto selectable_bible : bibles) {
     bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
   }
@@ -120,7 +121,7 @@ string editusfm_index (void * webserver_request)
   ss << "var usfmEditorWriteAccess = true;" << endl;
   ss << "var verticalCaretPosition = " << verticalCaretPosition << ";" << endl;
   string script = ss.str();
-  config_logic_swipe_enabled (webserver_request, script);
+  config::logic::swipe_enabled (webserver_request, script);
   view.set_variable ("script", script);
   
 
@@ -143,14 +144,14 @@ string editusfm_index (void * webserver_request)
   if (request->database_config_user ()->getFastEditorSwitchingAvailable ()) {
     view.enable_zone ("fastswitcheditor");
   }
-  if (config_logic_indonesian_cloud_free ()) {
+  if (config::logic::indonesian_cloud_free ()) {
     view.enable_zone ("fastswitcheditor");
   }
 
   page += view.render ("editusfm", "index");
   
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   
   return page;
