@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_EDITUSFM_OFFSET_H
-#define INCLUDED_EDITUSFM_OFFSET_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string editusfm_offset_url ();
+std::string editusfm_offset_url ();
 bool editusfm_offset_acl (void * webserver_request);
-string editusfm_offset (void * webserver_request);
-
-
-#endif
+std::string editusfm_offset (void * webserver_request);
