@@ -29,6 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <confirm/worker.h>
 #include <notes/logic.h>
 #include <filter/url.h>
+using namespace std;
 
 
 void email_receive ()
@@ -93,14 +94,14 @@ struct cstring {
 };
 
 
-void init_string (struct cstring *s) {
+void init_string (cstring *s) {
   s->len = 0;
   s->ptr = static_cast<char *>(malloc(s->len+1));
   s->ptr[0] = '\0';
 }
 
 
-size_t writefunc(void *ptr, size_t size, size_t nmemb, struct cstring *s)
+size_t writefunc(void *ptr, size_t size, size_t nmemb, cstring *s)
 {
   size_t new_len = s->len + size*nmemb;
   s->ptr = static_cast<char *>(realloc (s->ptr, new_len+1));
@@ -138,7 +139,7 @@ int email_receive_count (string& error, bool verbose)
   CURL *curl;
   CURLcode res = CURLE_OK;
 
-  struct cstring s;
+  cstring s;
   init_string (&s);
 
   curl = curl_easy_init ();
@@ -171,9 +172,11 @@ int email_receive_count (string& error, bool verbose)
   int mailcount = 0;
   
   if (res == CURLE_OK) {
-    string response = static_cast<char *>(s.ptr);
-    response = filter_string_trim (response);
-    mailcount = static_cast<int>(filter_string_explode (response, '\n').size());
+    if (s.ptr) {
+      string response = s.ptr;
+      response = filter_string_trim (response);
+      mailcount = static_cast<int>(filter_string_explode (response, '\n').size());
+    }
   } else {
     error = curl_easy_strerror (res);
   }
@@ -198,7 +201,7 @@ string email_receive_message (string& error)
   CURL *curl;
   CURLcode res = CURLE_OK;
 
-  struct cstring s;
+  cstring s;
   init_string (&s);
 
   curl = curl_easy_init ();
@@ -224,10 +227,10 @@ string email_receive_message (string& error)
   
   res = curl_easy_perform (curl);
 
-  string body;
+  string body {};
   
   if (res == CURLE_OK) {
-    body = static_cast<char *>(s.ptr);
+    if (s.ptr) body = s.ptr;
   } else {
     error = curl_easy_strerror (res);
   }
