@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,11 +27,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <sources/morphhb.h>
 #include <sources/oshb.h>
 #include <sources/styles.h>
+#include <sources/abbott-smith.h>
+#include <i18n/logic.h>
+using namespace std;
 
 
 int main (int argc, char **argv)
 {
-  cout << "Data Generator " << config_logic_version () << endl;
+  cout << "Data Generator " << config::logic::version () << endl;
   
   if (argc < 2) {
     cerr << "Please pass the document root folder as the first argument" << endl;
@@ -49,16 +52,23 @@ int main (int argc, char **argv)
     return EXIT_FAILURE;
   }
   string command = argv [2];
-  
-  string locale_command = "locale";
-  string sample_bible_command = "samplebible";
-  string mappings_command = "mappings";
-  string versifications_command = "versifications";
-  string morphhb_command = "morphhb";
-  string oshb_command = "oshb";
-  string stylesheet_command = "styles";
-  
-  if (command == locale_command) {
+
+  string i18n_command {"i18n"};
+  string locale_command {"locale"};
+  string sample_bible_command {"samplebible"};
+  string mappings_command {"mappings"};
+  string versifications_command {"versifications"};
+  string morphhb_command {"morphhb"};
+  string oshb_command {"oshb"};
+  string stylesheet_command {"styles"};
+  string abbott_smith_command {"abbott-smith"};
+
+  if (command == i18n_command) {
+
+    cout << "Translating untranslated GUI texts through Google Translate" << endl;
+    i18n_logic_augment_via_google_translate ();
+
+  } else if (command == locale_command) {
   
     cout << "Generating locale databases from the *.po files in folder locale" << endl;
     setup_generate_locale_databases (true);
@@ -92,11 +102,17 @@ int main (int argc, char **argv)
     
     cout << "Parsing style values and importing them into the default styles" << endl;
     sources_styles_parse ();
+
+  } else if (command == abbott_smith_command) {
+
+    cout << "Parsing Abbott-Smith's Manual Greek Lexicon into the abbottsmith database" << endl;
+    sources_abbott_smith_parse ();
     
   } else {
     
     cerr << "This command is unknown" << endl;
     cerr << "The following commands are supported:" << endl;
+    cerr << i18n_command << ": Translate untranslated GUI texts through Google Translate" << endl;
     cerr << locale_command << ": Generate locale databases from the *.po files in folder locale" << endl;
     cerr << sample_bible_command << ": Generate the sample Bible" << endl;
     cerr << mappings_command << ": Generate the default verse mappings database" << endl;
@@ -104,6 +120,7 @@ int main (int argc, char **argv)
     cerr << morphhb_command << ": Parse Open Scriptures Hebrew with limited morphology into the morphhb database" << endl;
     cerr << oshb_command << ": Parse Open Scriptures Hebrew Bible with morphology into the oshb database" << endl;
     cerr << stylesheet_command << ": Parse style values and import them into the default styles" << endl;
+    cout << abbott_smith_command << ": Parse Abbott-Smith's Manual Greek Lexicon into the abbottsmith database" << endl;
     
     return EXIT_FAILURE;
     
