@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,8 @@
  */
 
 
-#ifndef INCLUDED_EXPORT_TEXTUSFM_H
-#define INCLUDED_EXPORT_TEXTUSFM_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-void export_text_usfm_book (string bible, int book, bool log);
-
-
-#endif
+void export_text_usfm_book (std::string bible, int book, bool log);
