@@ -27,6 +27,8 @@
 #pragma GCC diagnostic ignored "-Wsign-conversion"
 #pragma GCC diagnostic ignored "-Weffc++"
 #pragma GCC diagnostic ignored "-Wold-style-cast"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wswitch-default"
 #include <dtl/dtl.hpp>
 #pragma GCC diagnostic pop
 #include <webserver/request.h>
@@ -37,8 +39,7 @@
 #include <text/text.h>
 #include <locale/translate.h>
 #include <developer/logic.h>
-
-
+using namespace std;
 using dtl::Diff;
 
 
@@ -356,7 +357,7 @@ void filter_diff_produce_verse_level (string bible, string directory)
   
   vector <int> books = database_modifications.getTeamDiffBooks (bible);
   for (auto book : books) {
-    string bookname = Database_Books::getEnglishFromId (book);
+    string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
     vector <int> chapters = database_modifications.getTeamDiffChapters (bible, book);
     for (auto chapter : chapters) {
       // Go through the combined verse numbers in the old and new chapter.
