@@ -22,6 +22,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/libraries.h>
 
 namespace filter::indonesian {
-string ourtranslation ();
-string mytranslation (const string & user);
+std::string ourtranslation ();
+std::string mytranslation (const std::string & user);
 }
