@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_FILTER_MAIL_H
-#define INCLUDED_FILTER_MAIL_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 #ifdef HAVE_CLOUD
-void filter_mail_dissect (string message, string & from, string & subject, string & plaintext);
-#endif
-
-
+void filter_mail_dissect (std::string message, std::string & from, std::string & subject, std::string & plaintext);
 #endif
