@@ -28,10 +28,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <assets/view.h>
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
 #pragma GCC diagnostic pop
-
-
+using namespace std;
 using namespace pugi;
 
 
@@ -113,7 +119,7 @@ Passage Passage::decode (const string& encoded)
 string filter_passage_display (int book, int chapter, string verse)
 {
   string display;
-  display.append (translate (Database_Books::getEnglishFromId (book).c_str()));
+  display.append (translate (database::books::get_english_from_id (static_cast<book_id>(book)).c_str()));
   display.append (" ");
   display.append (convert_to_string (chapter));
   if (!verse.empty ()) display.append (":" + verse);
@@ -167,25 +173,48 @@ Passage filter_integer_to_passage (int integer)
 
 // This filter takes $books as a string,
 // and looks whether it can be interpreted as a valid book in any way.
-// It returns a valid book identifier, or 0 in case no book could be interpreted.
-int filter_passage_interpret_book (string book)
+// It returns a valid book identifier,
+// or the unknown enum in case no book could be interpreted.
+book_id filter_passage_interpret_book_v2 (string book)
 {
   book = filter_string_trim (book);
+  
+  // Recognise the USFM book abbreviations.
+  {
+    book_id identifier = database::books::get_id_from_usfm (book);
+    if (identifier != book_id::_unknown) return identifier;
+  }
+
+  // Recognize the BibleWorks book abbreviations.
+  {
+    book_id identifier = database::books::get_id_from_bibleworks (book);
+    if (identifier != book_id::_unknown) return identifier;
+  }
+
+  // Handle names from BibleWorks when copying the verse list to the clipboard.
+  // These are not handled elsewhere.
+  if (book == "Cant") return book_id::_song_of_solomon;
+  if (book == "Mk") return book_id::_mark;
+  if (book == "Lk") return book_id::_luke;
+  if (book == "Jn") return book_id::_john;
+  if (book == "1 Jn") return book_id::_1_john;
+  if (book == "2 Jn") return book_id::_2_john;
+  if (book == "3 Jn") return book_id::_3_john;
 
   // Recognize names like "I Peter", where the "I" can also be "II" or "III".
   // Do the longest ones first.
   book = filter_string_str_replace ("III ", "3 ", book);
   book = filter_string_str_replace ("II ", "2 ", book);
   book = filter_string_str_replace ("I ", "1 ", book);
-
+  
   // Do case folding, i.e., work with lower case only.
   book = unicode_string_casefold (book);
-
+  
   // Remove any spaces from the book name and try with that too.
   string nospacebook = filter_string_str_replace (" ", "", book);
 
   // Store all of the available IDs locally.
-  vector <int> bookids = Database_Books::getIDs ();
+  vector <book_id> bookids = database::books::get_ids ();
   
   // Check on names entered like "Genesis" or "1 Corinthians", the full English name.
   // A bug was discovered so that "Judges" was interpreted as "Jude",
@@ -194,7 +223,7 @@ int filter_passage_interpret_book (string book)
   // In general, do exact matching first before moving on to similarity matching.
   // Compare with the translation to Bibledit's language too.
   for (auto identifier : bookids) {
-    string english = Database_Books::getEnglishFromId(identifier);
+    string english = database::books::get_english_from_id(identifier);
     if (english.empty()) continue;
     if (book == unicode_string_casefold(english)) return identifier;
     
@@ -207,17 +236,10 @@ int filter_passage_interpret_book (string book)
     
     if (nospacebook == unicode_string_casefold(localized)) return identifier;
   }
-
   
-  // Recognise the USFM book abbreviations.
-  {
-    int identifier = Database_Books::getIdFromUsfm (book);
-    if (identifier) return identifier;
-  }
-
   // Try the OSIS abbreviations.
   for (auto identifier : bookids) {
-    string osis = Database_Books::getOsisFromId(identifier);
+    string osis = database::books::get_osis_from_id(identifier);
     if (osis.empty()) continue;
     if (book == unicode_string_casefold(osis)) return identifier;
     if (nospacebook == unicode_string_casefold(osis)) return identifier;
@@ -229,7 +251,7 @@ int filter_passage_interpret_book (string book)
   
   // Try the abbreviations of BibleWorks.
   for (auto identifier : bookids) {
-    string bibleworks = Database_Books::getBibleworksFromId(identifier);
+    string bibleworks = database::books::get_bibleworks_from_id(identifier);
     if (bibleworks.empty()) continue;
     if (book == unicode_string_casefold(bibleworks)) return identifier;
     if (nospacebook == unicode_string_casefold(bibleworks)) return identifier;
@@ -238,20 +260,10 @@ int filter_passage_interpret_book (string book)
     if (book == unicode_string_casefold(localized)) return identifier;
     if (nospacebook == unicode_string_casefold(localized)) return identifier;
   }
-
-  // Handle names from BibleWorks when copying the verse list to the clipboard.
-  // These are not handled elsewhere.
-  if (book == "Cant") return 22;
-  if (book == "Mk") return 41;
-  if (book == "Lk") return 42;
-  if (book == "Jn") return 43;
-  if (book == "1 Jn") return 62;
-  if (book == "2 Jn") return 63;
-  if (book == "3 Jn") return 64;
-
+  
   // Try the abbreviations of the Online Bible.
   for (auto identifier : bookids) {
-    string onlinebible = Database_Books::getOnlinebibleFromId(identifier);
+    string onlinebible = database::books::get_onlinebible_from_id(identifier);
     if (onlinebible.empty()) continue;
     if (book == unicode_string_casefold(onlinebible)) return identifier;
     if (nospacebook == unicode_string_casefold(onlinebible)) return identifier;
@@ -260,15 +272,15 @@ int filter_passage_interpret_book (string book)
     if (book == unicode_string_casefold(localized)) return identifier;
     if (nospacebook == unicode_string_casefold(localized)) return identifier;
   }
-
+  
   // Do a case-insensitive search in the books database for something like the book given.
   {
-    int identifier = Database_Books::getIdLikeText (book);
-    if (identifier) return identifier;
+    book_id identifier = database::books::get_id_like_text (book);
+    if (identifier != book_id::_unknown) return identifier;
   }
   
   // Sorry, no book found.
-  return 0;
+  return book_id::_unknown;
 }
 
 
@@ -312,8 +324,8 @@ Passage filter_passage_explode_passage (string text)
   }
   string book = filter_string_implode (bits, " ");
   if (!book.empty()) {
-    int bk = filter_passage_interpret_book (book);
-    passage.m_book = bk;
+    book_id bk = filter_passage_interpret_book_v2 (book);
+    passage.m_book = static_cast<int>(bk);
   }
   // Return the result.
   return passage;
