@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,11 +33,11 @@ function passageConnectToLast () {
 function passageStartEditor (event) {
   event.preventDefault ();
   var a = $(this);
-  var href = a.attr ("href");
+  var passage = a.attr ("passage");
   $.ajax ({
     url: "/edit/edit",
     type: "GET",
-    data: { href: href },
+    data: { passage: passage },
     cache: false,
     success: function (response) {
       a.next ().html (response).fadeIn (100).delay (3000).fadeOut (1000);
