@@ -28,6 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <tlhelp32.h>
 #endif
 #include <developer/logic.h>
+using namespace std;
 
 
 // Internal declarations.
@@ -44,8 +45,8 @@ string filter_shell_escape_argument (string argument)
 
 
 // Runs shell $command in folder $directory, with $parameters.
-// If $output and $error are non-NULL, that is where the output of the shell command goes.
-// If they are NULL, the output of the shell command goes to the Journal.
+// If $output and $error are non-nullptr, that is where the output of the shell command goes.
+// If they are nullptr, the output of the shell command goes to the Journal.
 int filter_shell_run ([[maybe_unused]] string directory,
                       string command,
                       [[maybe_unused]] const vector <string> parameters,
@@ -122,7 +123,7 @@ int filter_shell_run (string command,
   }
   
   // Wait till child is ready.
-  wait(0);
+  wait(nullptr);
   close(fd);
   
   // Read the child's output.
