@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string images_index_url ();
+std::string images_index_url ();
 bool images_index_acl (void * webserver_request);
-string images_index (void * webserver_request);
+std::string images_index (void * webserver_request);
