@@ -29,11 +29,17 @@
 #include <database/abbottsmith.h>
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
 #pragma GCC diagnostic pop
 #include <webserver/request.h>
-
-
+using namespace std;
 using namespace pugi;
 
 
@@ -1481,7 +1487,7 @@ struct abbott_smith_walker: xml_tree_walker
   bool text_element_already_handled {false};
   string previous_element_name {};
 
-  virtual bool for_each (xml_node& node)
+  virtual bool for_each (xml_node& node) override
   {
     // Details of the current node.
     string clas = node.attribute ("class").value ();
