@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,11 @@
 static MUTEX_TYPE *mutex_buf = NULL;
 
 
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wunused-function"
+#pragma GCC diagnostic ignored "-Wunused-function"
+
+
 static void locking_function(int mode, int n, const char * file, int line)
 {
   if (mode & CRYPTO_LOCK)
@@ -48,11 +53,13 @@ static void locking_function(int mode, int n, const char * file, int line)
 }
 
 
-static unsigned long id_function(void)
+static unsigned long id_function()
 {
   return ((unsigned long)THREAD_ID);
 }
 
+#pragma clang diagnostic pop
+
 
 #endif
 
