@@ -21,7 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-extern vector <string> locale_translate_obfuscation_search;
-extern vector <string> locale_translate_obfuscation_replace;
-//void check_user_localization_preference (void * webserver_request);
-string translate (string english);
+extern std::vector <std::string> locale_translate_obfuscation_search;
+extern std::vector <std::string> locale_translate_obfuscation_replace;
+std::string translate (std::string english);
