@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_MANAGE_EXPORTS_H
-#define INCLUDED_MANAGE_EXPORTS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 const char * manage_exports_url ();
 bool manage_exports_acl (void * webserver_request);
-string manage_exports (void * webserver_request);
-
-
-#endif
+std::string manage_exports (void * webserver_request);
