@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <locale/translate.h>
 #include <assets/header.h>
 #include <menu/logic.h>
+using namespace std;
 
 
 string manage_index_url ()
@@ -42,10 +43,10 @@ string manage_index (void * webserver_request)
 {
   string page;
   Assets_Header header = Assets_Header (translate("Manage"), webserver_request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view;
   page += view.render ("manage", "index");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
