@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string navigation_update_url ();
+std::string navigation_update_url ();
 bool navigation_update_acl (void * webserver_request);
-string navigation_update (void * webserver_request);
+std::string navigation_update (void * webserver_request);
