@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
+using namespace std;
 
 
 string notes_assign_1_url ()
@@ -49,7 +50,7 @@ bool notes_assign_1_acl (void * webserver_request)
 
 string notes_assign_1 (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
   Database_NoteAssignment database_noteassignment;
@@ -80,17 +81,17 @@ string notes_assign_1 (void * webserver_request)
 
 
   // Note assignees.
-  string userblock;
+  stringstream userblock;
   vector <string> assignees = database_noteassignment.assignees (user);
   for (auto & assignee : assignees) {
-    userblock.append ("<li><a href=\"assign-1?id=" + convert_to_string (id) + "&assign=" + assignee + "\">" + assignee + "</a></li>\n");
+    userblock << "<li><a href=" << quoted ("assign-1?id=" + convert_to_string (id) + "&assign=" + assignee) << ">" << assignee << "</a></li>" << endl;
   }
-  view.set_variable ("userblock", userblock);
+  view.set_variable ("userblock", userblock.str());
   
   
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("notes", "assign-1");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
