@@ -32,33 +32,33 @@ public:
   static constexpr int notifyNoteComment = 2;
   static constexpr int notifyNoteDelete = 3;
   static constexpr int notifyMarkNoteForDeletion = 4;
-  int createNote (string bible, int book, int chapter, int verse, string summary, string contents, bool raw);
-  void setContent (int identifier, const string& content);
-  void addComment (int identifier, const string& comment);
-  void set_summary (int identifier, const string& summary);
+  int createNote (std::string bible, int book, int chapter, int verse, std::string summary, std::string contents, bool raw);
+  void setContent (int identifier, const std::string& content);
+  void addComment (int identifier, const std::string& comment);
+  void set_summary (int identifier, const std::string& summary);
   void subscribe (int identifier);
   void unsubscribe (int identifier);
-  void assignUser (int identifier, const string& user);
-  void unassignUser (int identifier, const string& user);
-  void setStatus (int identifier, const string& status);
-  void setPassages (int identifier, const vector <Passage> & passages);
+  void assignUser (int identifier, const std::string& user);
+  void unassignUser (int identifier, const std::string& user);
+  void setStatus (int identifier, const std::string& status);
+  void setPassages (int identifier, const std::vector <Passage> & passages);
   void setRawSeverity (int identifier, int severity);
-  void setBible (int identifier, const string& bible);
+  void setBible (int identifier, const std::string& bible);
   void markForDeletion (int identifier);
   void unmarkForDeletion (int identifier);
   void erase (int identifier);
   void handlerNewNote (int identifier);
   void handlerAddComment (int identifier);
-  void handlerAssignNote (int identifier, const string& user);
+  void handlerAssignNote (int identifier, const std::string& user);
   void handlerMarkNoteForDeletion (int identifier);
   void handlerDeleteNote (int identifier);
-  bool handleEmailNew (string from, string subject, string body);
-  bool handleEmailComment (string from, string subject, string body);
-  string generalBibleName ();
+  bool handleEmailNew (std::string from, std::string subject, std::string body);
+  bool handleEmailComment (std::string from, std::string subject, std::string body);
+  std::string generalBibleName ();
 private:
   void * webserver_request {nullptr};
   void notifyUsers (int identifier, int notification);
-  void emailUsers (int identifier, const string& label, string bible, const vector <string> & users, bool postpone);
+  void emailUsers (int identifier, const std::string& label, std::string bible, const std::vector <std::string> & users, bool postpone);
 };
 
 void notes_logic_maintain_note_assignees (bool force);
