@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string notes_note_url ();
+std::string notes_note_url ();
 bool notes_note_acl (void * webserver_request);
-string notes_note (void * webserver_request);
+std::string notes_note (void * webserver_request);
