@@ -32,6 +32,7 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
+using namespace std;
 
 
 string notes_status_n_url ()
@@ -67,6 +68,6 @@ string notes_status_n (void * webserver_request)
   
   
   page += view.render ("notes", "status-n");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
