@@ -24,7 +24,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <styles/logic.h>
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Weffc++"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifndef HAVE_PUGIXML
 #include <pugixml/pugixml.hpp>
+#endif
+#ifdef HAVE_PUGIXML
+#include <pugixml.hpp>
+#endif
 #pragma GCC diagnostic pop
 
 using namespace pugi;
@@ -32,15 +39,15 @@ using namespace pugi;
 class odf_text
 {
 public:
-  odf_text (string bible_in);
+  odf_text (std::string bible);
   ~odf_text ();
-  void new_paragraph (string style = styles_logic_standard_sheet ());
-  void add_text (string text);
-  void new_heading1 (string text, bool hide = false);
+  void new_paragraph (std::string style = styles_logic_standard_sheet ());
+  void add_text (std::string text);
+  void new_heading1 (std::string text, bool hide = false);
   void create_page_break_style ();
   void new_page_break ();
-  void create_paragraph_style (string name,
-                               string fontname,
+  void create_paragraph_style (std::string name,
+                               std::string fontname,
                                float fontsize,
                                int italic, int bold, int underline,
                                int smallcaps,
@@ -50,41 +57,41 @@ public:
                                float firstlineindent,
                                bool keep_with_next,
                                int dropcaps);
-  void update_current_paragraph_style (string name);
+  void update_current_paragraph_style (std::string name);
   void open_text_style (Database_Styles_Item style, bool note, bool embed);
   void close_text_style (bool note, bool embed);
-  void place_text_in_frame (string text, string style, float fontsize, int italic, int bold);
+  void place_text_in_frame (std::string text, std::string style, float fontsize, int italic, int bold);
   void create_superscript_style ();
-  void add_note (string caller, string style, bool endnote = false);
-  void add_note_text (string text);
+  void add_note (std::string caller, std::string style, bool endnote = false);
+  void add_note_text (std::string text);
   void close_current_note ();
-  void save (string name);
-  string current_paragraph_style {};
-  string current_paragraph_content {};
-  vector <string> current_text_style {};
-  void add_image (string alt, string src, string caption);
+  void save (std::string name);
+  std::string m_current_paragraph_style {};
+  std::string m_current_paragraph_content {};
+  std::vector <std::string> m_current_text_style {};
+  void add_image (std::string style, std::string alt, std::string src, std::string caption);
   void add_tab ();
 private:
-  string bible {};
-  string unpacked_odt_folder {};
+  std::string m_bible {};
+  std::string unpacked_odt_folder {};
   xml_document content_dom {}; // The content.xml DOMDocument.
   xml_node office_text_node {}; // The office:text DOMNode.
   xml_document styles_dom {}; // The styles.xml DOMDocument.
-  vector <string> created_styles {}; // An array with styles already created in the $stylesDom.
+  std::vector <std::string> created_styles {}; // An array with styles already created in the $stylesDom.
   xml_node office_styles_node {}; // The office:styles DOMNode.
   xml_node current_text_p_node {}; // The current text:p DOMElement.
-  bool current_text_p_node_opened {false}; // Whether the text:p element has been opened.
+  bool m_current_text_p_node_opened {false}; // Whether the text:p element has been opened.
   xml_attribute current_text_p_node_style_name {}; // The DOMAttr of the name of the style of the current text:p element.
-  int frame_count {0};
-  int note_count {0};
+  int m_frame_count {0};
+  int m_note_count {0};
   xml_node note_text_p_dom_element {}; // The text:p DOMElement of the current footnote, if any.
-  bool note_text_p_opened {false}; // Whether the text:p for notes has been opened.
-  vector <string> current_note_text_style {};
+  bool m_note_text_p_opened {false}; // Whether the text:p for notes has been opened.
+  std::vector <std::string> m_current_note_text_style {};
   void initialize_content_xml ();
   void initialize_styles_xml ();
-  void new_named_heading (string style, string text, bool hide = false);
-  string convert_style_name (string style);
-  int image_counter {0};
+  void new_named_heading (std::string style, std::string text, bool hide = false);
+  std::string convert_style_name (std::string style);
+  int m_image_counter {0};
   bool automatic_note_caller {false};
 };
 
