@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/url.h>
 #include <database/books.h>
+using namespace std;
 
 
 // Class for creating input files for the Online Bible compiler.
@@ -45,7 +46,7 @@ void OnlineBible_Text::newVerse (int bookIdentifier, int chapterNumber, int vers
   storeData ();
   // Store passage and any text only in case the book is valid,
   // and the chapter and verse are non-zero.
-  string book = Database_Books::getOnlinebibleFromId (bookIdentifier);
+  string book = database::books::get_onlinebible_from_id (static_cast<book_id>(bookIdentifier));
   if (!book.empty()) {
     if (chapterNumber > 0) {
       if (verseNumber > 0) {
