@@ -32,6 +32,7 @@
 #include <database/config/general.h>
 #include <tasks/logic.h>
 #include <journal/index.h>
+using namespace std;
 
 
 string paratext_index_url ()
@@ -52,7 +53,7 @@ string paratext_index (void * webserver_request)
 
 
   string page;
-  page = Assets_Page::header (translate ("Paratext"), webserver_request);
+  page = assets_page::header (translate ("Paratext"), webserver_request);
   Assets_View view;
   string success;
   string error;
@@ -177,7 +178,7 @@ string paratext_index (void * webserver_request)
   
   page += view.render ("paratext", "index");
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   return page;
 }
