@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string paratext_index_url ();
+std::string paratext_index_url ();
 bool paratext_index_acl (void * webserver_request);
-string paratext_index (void * webserver_request);
+std::string paratext_index (void * webserver_request);
