@@ -21,4 +21,4 @@
 
 #include <config/libraries.h>
 
-void pugixml_utils_error_logger (void * pugi_xml_parse_result, const string & xml);
+void pugixml_utils_error_logger (void * pugi_xml_parse_result, const std::string & xml);
