@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string editone_index_url ();
+std::string editone_index_url ();
 bool editone_index_acl ();
-string editone_index (void * webserver_request);
+std::string editone_index (void * webserver_request);
