@@ -22,4 +22,4 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/libraries.h>
 #include <filter/passage.h>
 
-vector <Passage> related_logic_get_verses (const vector <Passage> & input);
+std::vector <Passage> related_logic_get_verses (const std::vector <Passage> & input);
