@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_imagefetch_url ();
+std::string resource_imagefetch_url ();
 bool resource_imagefetch_acl (void * webserver_request);
-string resource_imagefetch (void * webserver_request);
+std::string resource_imagefetch (void * webserver_request);
