@@ -49,6 +49,7 @@
 #include <related/logic.h>
 #include <developer/logic.h>
 #include <database/logic.h>
+using namespace std;
 
 
 /*
@@ -94,14 +95,14 @@ Stages to retrieve resource content and serve it.
 
 vector <string> resource_logic_get_names (void * webserver_request, bool bibles_only)
 {
-  vector <string> names;
+  vector <string> names {};
   
   // Bibles the user has read access to.
-  vector <string> bibles = AccessBible::Bibles (webserver_request);
+  vector <string> bibles = access_bible::bibles (webserver_request);
   names.insert (names.end(), bibles.begin (), bibles.end());
   
   // USFM resources.
-  Database_UsfmResources database_usfmresources;
+  Database_UsfmResources database_usfmresources {};
   vector <string> usfm_resources = database_usfmresources.getResources ();
   names.insert (names.end(), usfm_resources.begin(), usfm_resources.end());
   
@@ -111,7 +112,7 @@ vector <string> resource_logic_get_names (void * webserver_request, bool bibles_
   
   // Image resources.
   if (!bibles_only) {
-    Database_ImageResources database_imageresources;
+    Database_ImageResources database_imageresources {};
     vector <string> image_resources = database_imageresources.names ();
     names.insert (names.end (), image_resources.begin(), image_resources.end());
   }
@@ -122,10 +123,14 @@ vector <string> resource_logic_get_names (void * webserver_request, bool bibles_
     names.insert (names.end (), lexicon_resources.begin(), lexicon_resources.end());
   }
   
-  // SWORD resources
+  // SWORD resources.
   vector <string> sword_resources = sword_logic_get_available ();
   names.insert (names.end (), sword_resources.begin(), sword_resources.end());
   
+  // Bible Gateway resources.
+  vector <string> bible_gateway_resources = resource_logic_bible_gateway_module_list_get ();
+  names.insert (names.end (), bible_gateway_resources.begin(), bible_gateway_resources.end());
+  
   sort (names.begin(), names.end());
   
   return names;
@@ -601,12 +606,12 @@ void resource_logic_import_images (string resource, string path)
       Database_Logs::log ("Processing PDF: " + basename);
       
       // Retrieve PDF information.
-      filter_shell_run ("", "pdfinfo", {path}, NULL, NULL);
+      filter_shell_run ("", "pdfinfo", {path}, nullptr, nullptr);
 
       // Convert the PDF file to separate images.
       string folder = filter_url_tempfile ();
       filter_url_mkdir (folder);
-      filter_shell_run (folder, "pdftocairo", {"-jpeg", path}, NULL, NULL);
+      filter_shell_run (folder, "pdftocairo", {"-jpeg", path}, nullptr, nullptr);
       // Add the images to the ones to be processed.
       filter_url_recursive_scandir (folder, paths);
       
@@ -817,7 +822,7 @@ void resource_logic_create_cache ()
   size_t pos = signature.find_last_of (" ");
   string resource = signature.substr (0, pos);
   int book = convert_to_int (signature.substr (pos++));
-  string bookname = Database_Books::getEnglishFromId (book);
+  string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
   
   // Whether it's a SWORD module.
   string sword_module = sword_logic_get_remote_module (resource);
@@ -1129,7 +1134,7 @@ struct bible_gateway_walker: xml_tree_walker
   string text {};
   vector <string> footnotes {};
 
-  virtual bool for_each (xml_node& node)
+  virtual bool for_each (xml_node& node) override
   {
     // Details of the current node.
     string classname = node.attribute ("class").value ();
@@ -1329,16 +1334,16 @@ vector <string> resource_logic_study_light_module_list_get ()
 // Get the slightly formatted of a passage of a StudyLight resource.
 string resource_logic_study_light_get (string resource, int book, int chapter, int verse)
 {
-  string result;
+  string result {};
 
 #ifdef HAVE_CLOUD
   // Transform the full name to the abbreviation for the website, e.g.:
   // "Adam Clarke Commentary (acc)" becomes "acc".
   size_t pos = resource.find_last_of ("(");
-  if (pos == string::npos) return "";
+  if (pos == string::npos) return string();
   resource.erase (0, pos + 1);
   pos = resource.find (")");
-  if (pos == string::npos) return "";
+  if (pos == string::npos) return string();
   resource.erase (pos);
   
   // The resource abbreviation might look like this:
@@ -1347,24 +1352,39 @@ string resource_logic_study_light_get (string resource, int book, int chapter, i
   resource.erase (0, 11);
   
   // Example URL: https://www.studylight.org/commentaries/eng/acc/revelation-1.html
-  string url;
+  string url {};
   url.append ("http://www.studylight.org/commentaries/");
   url.append (resource + "/");
   url.append (resource_external_convert_book_studylight (book));
   url.append ("-" + convert_to_string (chapter) + ".html");
   
   // Get the html from the server.
-  string error;
+  string error {};
   string html = resource_logic_web_or_cache_get (url, error);
 
   // It appears that the html from this website is not well-formed.
   // It cannot be loaded as an XML document without errors and missing text.
   // Therefore the html is tidied first.
-  html = filter_string_tidy_invalid_html (html);
+  html = filter_string_fix_invalid_html_gumbo (html);
+  
+  string start_key = R"(<div class="ptb10">)";
+  vector <int> class_lightgrey_book {
+    23, // Isaiah
+    27, // Daniel
+    52, // 1 Thessalonians
+    53, // 2 Thessalonians
+    54, // 1 Timothy
+    58, // Hebrews
+  };
+  if (in_array(book, class_lightgrey_book)) {
+    start_key = R"(<div class="tl-lightgrey ptb10">)";
+  }
+  pos = html.find(start_key);
+  if (pos != string::npos) html.erase (0, pos);
 
   // Parse the html into a DOM.
-  string verse_s = convert_to_string (verse);
-  xml_document document;
+  string verse_s {convert_to_string (verse)};
+  xml_document document {};
   document.load_string (html.c_str());
 
   // Example verse indicator within the XML:
@@ -1517,6 +1537,7 @@ vector <string> resource_logic_easy_english_bible_pages (int book, int chapter)
     case 64: return { "3john-lbw" }; // 3 John.
     case 65: return { "jude-lbw", "jude-nh-lbw" }; // Jude.
     case 66: return { "revelation-lbw" }; // Revelation.
+    default: return {};
   }
   return {};
 }
@@ -1526,7 +1547,7 @@ struct easy_english_bible_walker: xml_tree_walker
 {
   string text {};
 
-  virtual bool for_each (xml_node& node)
+  virtual bool for_each (xml_node& node) override
   {
     // Handle this node if it's a text node.
     if (node.type() == pugi::node_pcdata) {
@@ -1554,11 +1575,11 @@ string resource_logic_easy_english_bible_get (int book, int chapter, int verse)
 #ifdef HAVE_CLOUD
 
   // The combined text result taken from the commentary.
-  string result;
+  string result {};
 
   // This resource may have one or more commentaries per book.
   // This means that the URLs may be one or more.
-  vector <string> urls;
+  vector <string> urls {};
   {
     vector <string> pages = resource_logic_easy_english_bible_pages (book, chapter);
     for (auto page : pages) {
@@ -1576,24 +1597,38 @@ string resource_logic_easy_english_bible_get (int book, int chapter, int verse)
   for (auto url : urls) {
     
     // Flag for whether the current paragraph contains the desired passage.
-    bool near_passage = false;
+    bool near_passage {false};
     // Flag for whether the current paragraph is for the exact verse number.
-    bool at_passage = false;
+    bool at_passage {false};
     
     // Get the html from the server.
-    string error;
+    string error {};
     string html = resource_logic_web_or_cache_get (url, error);
 
     // It appears that the html from this website is not well-formed.
     // It cannot be loaded as an XML document without errors and missing text.
     // Therefore the html is tidied first.
-    html = filter_string_tidy_invalid_html (html);
+    html = filter_string_fix_invalid_html_gumbo (html);
 
+    // The html from this website requires further cleaning.
+    // One issue is that instead of  class="Section1"  it has  class=Section1
+    // Notice the missing quotes around the class name.
+    // Call libtidy to further tidy this heml up.
+    html = filter_string_fix_invalid_html_tidy (html);
+
+    // The document has one main div like this:
+    // <div class="Section1">
+    // Or: <div class="WordSection1"> like in Exodus.
+    size_t pos = html.find(R"(<div class="Section1">)");
+    if (pos == string::npos) {
+      pos = html.find(R"(<div class="WordSection1">)");
+    }
+    if (pos != string::npos) html.erase (0, pos);
+    
     // Parse the html into a DOM.
-    string verse_s = convert_to_string (verse);
-    xml_document document;
+    xml_document document {};
     document.load_string (html.c_str());
-
+    
     // The document has one main div like this:
     // <div class="Section1">
     // Or: <div class="WordSection1"> like in Exodus.
@@ -1665,8 +1700,12 @@ string resource_logic_easy_english_bible_get (int book, int chapter, int verse)
           }
         }
 
-        // If still at the correct verse, add the paragraph text.
+        // If still at the correct verse, add the contents.
         if (at_passage) {
+          // The html from this website is encoded as charset=windows-1252.
+          // Convert that to UTF0-8.
+          paragraph = convert_windows1252_to_utf8 (paragraph);
+          // Add this paragraph to the resulting text.
           result.append ("<p>");
           result.append (paragraph);
           result.append ("</p>");
@@ -2035,6 +2074,21 @@ string resource_logic_assemble_comparative_resource (string title,
 }
 
 
+string resource_logic_comparative_resources_list_path ()
+{
+  return filter_url_create_root_path ({database_logic_databases (), "client", "comparative_resources.txt"});
+}
+
+
+// Get the list of comparative resources on a client device.
+vector <string> resource_logic_comparative_resources_get_list_on_client ()
+{
+  string path = resource_logic_comparative_resources_list_path ();
+  string contents = filter_url_file_get_contents (path);
+  return filter_string_explode (contents, '\n');
+}
+
+
 bool resource_logic_is_translated (const string & resource)
 {
   return resource_logic_parse_translated_resource(resource);
@@ -2099,7 +2153,7 @@ string resource_logic_translated_resources_list_path ()
 }
 
 
-// Get the list of Translated resources on a client device.
+// Get the list of translated resources on a client device.
 vector <string> resource_logic_translated_resources_get_list_on_client ()
 {
   string path = resource_logic_translated_resources_list_path ();
