@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_organize_url ();
+std::string resource_organize_url ();
 bool resource_organize_acl (void * webserver_request);
-string resource_organize (void * webserver_request);
+std::string resource_organize (void * webserver_request);
