@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string resource_studylight_url ();
+std::string resource_studylight_url ();
 bool resource_studylight_acl (void * webserver_request);
-string resource_studylight (void * webserver_request);
+std::string resource_studylight (void * webserver_request);
