@@ -32,6 +32,7 @@
 #include <journal/index.h>
 #include <sword/logic.h>
 #include <menu/logic.h>
+using namespace std;
 
 
 string resource_sword_url ()
@@ -75,7 +76,7 @@ string resource_sword (void * webserver_request)
   
   string page;
   Assets_Header header = Assets_Header (translate("Resources"), request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view;
 
@@ -117,6 +118,6 @@ string resource_sword (void * webserver_request)
   
   
   page += view.render ("resource", "sword");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
