@@ -32,6 +32,7 @@
 #include <dialog/entry.h>
 #include <dialog/yes.h>
 #include <database/userresources.h>
+using namespace std;
 
 
 string resource_user9edit_url ()
@@ -53,7 +54,7 @@ string resource_user9edit (void * webserver_request)
   
   string page;
   Assets_Header header = Assets_Header (translate("User resources"), request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view;
   string error, success;
@@ -110,6 +111,6 @@ string resource_user9edit (void * webserver_request)
   view.set_variable ("success", success);
   view.set_variable ("error", error);
   page += view.render ("resource", "user9edit");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
