@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <menu/logic.h>
 #include <database/userresources.h>
 #include <access/logic.h>
+using namespace std;
 
 
 string resource_user9view_url ()
@@ -40,18 +41,18 @@ string resource_user9view_url ()
 
 bool resource_user9view_acl (void * webserver_request)
 {
-  return access_logic_privilege_view_resources (webserver_request);
+  return access_logic::privilege_view_resources (webserver_request);
 }
 
 
 string resource_user9view (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   
   string page;
   Assets_Header header = Assets_Header (translate("User resources"), request);
-  header.addBreadCrumb (menu_logic_translate_menu (), menu_logic_translate_text ());
+  header.add_bread_crumb (menu_logic_translate_menu (), menu_logic_translate_text ());
   page = header.run ();
   Assets_View view;
   
@@ -69,6 +70,6 @@ string resource_user9view (void * webserver_request)
 
    
   page += view.render ("resource", "user9view");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
