@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <filter/url.h>
 #include <webserver/request.h>
 #include <rss/logic.h>
+using namespace std;
 
 
 string rss_feed_url ()
@@ -29,22 +30,20 @@ string rss_feed_url ()
 }
 
 
-bool rss_feed_acl (void * webserver_request)
+bool rss_feed_acl ([[maybe_unused]] void * webserver_request)
 {
-  (void) webserver_request;
   return true;
 }
 
 
-string rss_feed (void * webserver_request)
+string rss_feed ([[maybe_unused]] void * webserver_request)
 {
   string xml;
 #ifdef HAVE_CLOUD
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   request->response_content_type = "application/rss+xml";
   string path = rss_logic_xml_path ();
   xml = filter_url_file_get_contents (path);
 #endif
-  (void) webserver_request;
   return xml;
 }
