@@ -32,6 +32,7 @@
 #include <ipc/focus.h>
 #include <menu/logic.h>
 #include <dialog/list2.h>
+using namespace std;
 
 
 string search_replace2_url ()
@@ -43,7 +44,7 @@ string search_replace2_url ()
 bool search_replace2_acl (void * webserver_request)
 {
   if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return write;
 }
 
@@ -63,13 +64,13 @@ string search_replace2 (void * webserver_request)
 
   string page;
   Assets_Header header = Assets_Header (translate("Replace"), request);
-  header.addBreadCrumb (menu_logic_search_menu (), menu_logic_search_text ());
+  header.add_bread_crumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
   Assets_View view;
 
   {
     string bible_html;
-    vector <string> bibles = AccessBible::Bibles (request);
+    vector <string> bibles = access_bible::bibles (request);
     for (auto selectable_bible : bibles) {
       bible_html = Options_To_Select::add_selection (selectable_bible, selectable_bible, bible_html);
     }
@@ -80,6 +81,6 @@ string search_replace2 (void * webserver_request)
   string script = "var searchBible = \"" + bible + "\";";
   view.set_variable ("script", script);
   page += view.render ("search", "replace2");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
