@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string search_replace2_url ();
+std::string search_replace2_url ();
 bool search_replace2_acl (void * webserver_request);
-string search_replace2 (void * webserver_request);
+std::string search_replace2 (void * webserver_request);
