@@ -21,6 +21,6 @@
 
 #include <config/libraries.h>
 
-string search_similar_url ();
+std::string search_similar_url ();
 bool search_similar_acl (void * webserver_request);
-string search_similar (void * webserver_request);
+std::string search_similar (void * webserver_request);
