@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@
  */
 
 
-#ifndef INCLUDED_SEARCH_STRONG_H
-#define INCLUDED_SEARCH_STRONG_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string search_strong_url ();
+std::string search_strong_url ();
 bool search_strong_acl (void * webserver_request);
-string search_strong (void * webserver_request);
-
-
-#endif
+std::string search_strong (void * webserver_request);
