@@ -21,7 +21,7 @@
 
 #include <config/libraries.h>
 
-string sendreceive_bibles_sendreceive_text ();
-string sendreceive_bibles_up_to_date_text ();
+std::string sendreceive_bibles_sendreceive_text ();
+std::string sendreceive_bibles_up_to_date_text ();
 void sendreceive_bibles ();
 void sendreceive_bibles_kick_watchdog ();
