@@ -33,9 +33,10 @@
 #include <sync/logic.h>
 #include <sync/changes.h>
 #include <checksum/logic.h>
+using namespace std;
 
 
-int sendreceive_changes_watchdog = 0;
+int sendreceive_changes_watchdog {0};
 
 
 void send_receive_changes_done ()
@@ -66,7 +67,7 @@ string sendreceive_changes_up_to_date_text ()
 void sendreceive_changes ()
 {
   if (sendreceive_changes_watchdog) {
-    int time = filter_date_seconds_since_epoch ();
+    int time = filter::date::seconds_since_epoch ();
     if (time < (sendreceive_changes_watchdog + 900)) {
       Database_Logs::log (sendreceive_changes_text () + translate("Still busy"), Filter_Roles::translator ());
       return;
@@ -109,7 +110,7 @@ void sendreceive_changes ()
     return;
   }
   string user = users [0];
-  request.session_logic ()->setUsername (user);
+  request.session_logic ()->set_username (user);
   string password = request.database_users ()->get_md5 (user);
   
   
@@ -193,8 +194,8 @@ void sendreceive_changes ()
     return;
   }
   {
-    vector <string> ids = filter_string_explode (response, '\n');
-    for (auto & id : ids) server_identifiers.push_back (convert_to_int (id));
+    vector <string> ids2 = filter_string_explode (response, '\n');
+    for (auto & id : ids2) server_identifiers.push_back (convert_to_int (id));
   }
 
   
@@ -275,5 +276,5 @@ void sendreceive_changes ()
 
 void sendreceive_changes_kick_watchdog ()
 {
-  sendreceive_changes_watchdog = filter_date_seconds_since_epoch ();
+  sendreceive_changes_watchdog = filter::date::seconds_since_epoch ();
 }
