@@ -35,9 +35,10 @@
 #include <database/logs.h>
 #include <database/config/general.h>
 #include <database/privileges.h>
+using namespace std;
 
 
-int sendreceive_files_watchdog = 0;
+int sendreceive_files_watchdog {0};
 
 
 void sendreceive_files_done ()
@@ -69,7 +70,7 @@ void sendreceive_files ()
 {
   // Watchdog handler.
   if (sendreceive_files_watchdog) {
-    int time = filter_date_seconds_since_epoch ();
+    int time = filter::date::seconds_since_epoch ();
     if (time < (sendreceive_files_watchdog + 900)) {
       Database_Logs::log (sendreceive_files_text () + translate("Still busy"), Filter_Roles::translator ());
       return;
@@ -122,7 +123,7 @@ void sendreceive_files ()
   post ["v"] = convert_to_string (version);
   string error;
   string response;
-  int iresponse = 0;
+  int iresponse { 0 };
   
 
   // Request the checksum of all relevant files on the server.
@@ -167,8 +168,8 @@ void sendreceive_files ()
       return;
     }
     iresponse = convert_to_int (response);
-    int checksum = Sync_Logic::files_get_directory_checksum (directory);
-    if (iresponse == checksum) {
+    int checksum_d = Sync_Logic::files_get_directory_checksum (directory);
+    if (iresponse == checksum_d) {
       continue;
     }
 
@@ -212,9 +213,9 @@ void sendreceive_files ()
         sendreceive_files_done ();
         return;
       }
-      int iresponse = convert_to_int (response);
-      int checksum = Sync_Logic::files_get_file_checksum (directory, file);
-      if (iresponse == checksum) {
+      int iresponse_file = convert_to_int (response);
+      int checksum_file = Sync_Logic::files_get_file_checksum (directory, file);
+      if (iresponse_file == checksum_file) {
         continue;
       }
       
@@ -261,5 +262,5 @@ void sendreceive_files ()
 
 void sendreceive_files_kick_watchdog ()
 {
-  sendreceive_files_watchdog = filter_date_seconds_since_epoch ();
+  sendreceive_files_watchdog = filter::date::seconds_since_epoch ();
 }
