@@ -21,8 +21,8 @@
 
 #include <config/libraries.h>
 
-string sendreceive_notes_sendreceive_text ();
-string sendreceive_notes_up_to_date_text ();
+std::string sendreceive_notes_sendreceive_text ();
+std::string sendreceive_notes_up_to_date_text ();
 void sendreceive_notes ();
 bool sendreceive_notes_upload ();
 bool sendreceive_notes_download (int lowId, int highId);
