@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/roles.h>
 #include <config/globals.h>
 #include <user/logic.h>
+using namespace std;
 
 
 // The username and password for a demo installation, and for a disconnected client installation
@@ -80,35 +81,35 @@ void Session_Logic::open ()
   if (openAccess ()) return;
   if (clientAccess ()) return;
 
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   // Work around a weird bug where the user_agent's size is 140735294083184 leading to a crash.
-  if (request->user_agent.size () > 10000) return;
+  if (request->user_agent.size () > 10'000) return;
 
   // Discard empty cookies right-away.
   // Don't regard this as something that triggers the brute force attach mitigation mechanism.
   string cookie = request->session_identifier;
   if (cookie.empty ()) {
-    setUsername ("");
+    set_username ("");
     logged_in = false;
     return;
   }
   
   bool daily;
-  string username = Database_Login::getUsername (cookie, daily);
-  if (!username.empty ()) {
-    setUsername (username);
+  string username_from_cookie = Database_Login::getUsername (cookie, daily);
+  if (!username_from_cookie.empty ()) {
+    set_username (username_from_cookie);
     logged_in = true;
     if (daily) request->resend_cookie = true;
     touch_enabled = Database_Login::getTouchEnabled (cookie);
   } else {
-    setUsername ("");
+    set_username (string());
     logged_in = false;
   }
 }
 
 
-void Session_Logic::setUsername (string name)
+void Session_Logic::set_username (string name)
 {
   username = name;
 }
@@ -118,7 +119,7 @@ bool Session_Logic::openAccess ()
 {
   // Open access if it is flagged as such.
   if (config_globals_open_installation) {
-    setUsername (session_admin_credentials ());
+    set_username (session_admin_credentials ());
     level = Filter_Roles::admin ();
     logged_in = true;
     return true;
@@ -130,9 +131,10 @@ bool Session_Logic::openAccess ()
 // Returns IP blocks of remote address.
 string Session_Logic::remoteAddress ()
 {
-  vector <string> blocks = filter_string_explode (((Webserver_Request *) webserver_request)->remote_address, '.');
-  string address = "";
-  unsigned int num_blocks = abs (check_ip_blocks);
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  vector <string> blocks = filter_string_explode (request->remote_address, '.');
+  string address;
+  size_t num_blocks = static_cast<size_t> (abs (check_ip_blocks));
   if (num_blocks > blocks.size ()) num_blocks = blocks.size ();
   for (unsigned int i = 0; i < num_blocks; i++) {
     address += blocks [i] + ".";
@@ -147,7 +149,8 @@ string Session_Logic::fingerprint ()
   string fingerprint = "";
   // fingerprint += $_SERVER ['HTTP_CONNECTION']; Unstable fingerprint. No use for persistent login.
   // fingerprint += $_SERVER ['HTTP_ACCEPT_ENCODING']; Unstable fingerprint. No use for persistent login.
-  fingerprint += ((Webserver_Request *) webserver_request)->accept_language;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  fingerprint += request->accept_language;
   return fingerprint;
 }
 
@@ -155,34 +158,44 @@ string Session_Logic::fingerprint ()
 // Attempts to log into the system.
 // Records whether the user logged in from a touch-enabled device.
 // Returns boolean success.
-bool Session_Logic::attemptLogin (string user_or_email, string password, bool touch_enabled)
+bool Session_Logic::attempt_login (string user_or_email, string password,
+                                   bool touch_enabled_in, bool skip_checks)
 {
   // Brute force attack mitigation.
   if (!user_logic_login_failure_check_okay ()) {
     return false;
   }
 
-  Database_Users database = Database_Users ();
+  Database_Users database_users = Database_Users ();
   bool login_okay = false;
 
   // Match username and email.
-  if (database.matchUserPassword (user_or_email, password)) {
+  if (database_users.matchUserPassword (user_or_email, password)) {
     login_okay = true;
   }
 
   // Match password and email.
-  if (database.matchEmailPassword (user_or_email, password)) {
+  if (database_users.matchEmailPassword (user_or_email, password)) {
     login_okay = true;
     // Fetch username that belongs to the email address that was used to login.
-    user_or_email = database.getEmailToUser (user_or_email);
+    user_or_email = database_users.getEmailToUser (user_or_email);
+  }
+  
+  // The routine can skip the checks, as in the case of a confirmation link.
+  if (skip_checks) {
+    login_okay = true;
+    // When skipping checks, the email is passed, so fetch the username from that.
+    user_or_email = database_users.getEmailToUser (user_or_email);
+    if (user_or_email.empty()) login_okay = false;
   }
   
   if (login_okay) {
     open ();
-    setUsername (user_or_email);
+    set_username (user_or_email);
     logged_in = true;
-    string cookie = ((Webserver_Request *) webserver_request)->session_identifier;
-    Database_Login::setTokens (user_or_email, "", "", "", cookie, touch_enabled);
+    Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+    string cookie = request->session_identifier;
+    Database_Login::setTokens (user_or_email, "", "", "", cookie, touch_enabled_in);
     currentLevel (true);
     return true;
   } else {
@@ -246,10 +259,10 @@ int Session_Logic::currentLevel (bool force)
 
 void Session_Logic::logout ()
 {
-  string username = currentUser ();
-  string cookie = ((Webserver_Request *) webserver_request)->session_identifier;
-  Database_Login::removeTokens (username, cookie);
-  setUsername ("");
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string cookie = request->session_identifier;
+  Database_Login::removeTokens (currentUser (), cookie);
+  set_username (string());
   level = Filter_Roles::guest();
 }
 
@@ -261,7 +274,7 @@ bool Session_Logic::clientAccess ()
   // or as the admin in case no user has been set up yet.
   if (config_globals_client_prepared) {
     Database_Users database_users;
-    vector <string> users = database_users.getUsers ();
+    vector <string> users = database_users.get_users ();
     string user;
     if (users.empty ()) {
       user = session_admin_credentials ();
@@ -270,7 +283,7 @@ bool Session_Logic::clientAccess ()
       user = users [0];
       level = database_users.get_level (user);
     }
-    setUsername (user);
+    set_username (user);
     logged_in = true;
     return true;
   }
@@ -278,9 +291,10 @@ bool Session_Logic::clientAccess ()
 }
 
 
-void Session_Logic::switchUser (string username)
+void Session_Logic::switch_user (string new_user)
 {
-  string cookie = ((Webserver_Request *) webserver_request)->session_identifier;
-  Database_Login::removeTokens (username, cookie);
-  Database_Login::renameTokens (currentUser (), username, cookie);
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
+  string cookie = request->session_identifier;
+  Database_Login::removeTokens (new_user, cookie);
+  Database_Login::renameTokens (currentUser (), new_user, cookie);
 }
