@@ -23,4 +23,4 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 const char * session_logout_url ();
 bool session_logout_acl (void * webserver_request);
-string session_logout (void * webserver_request);
+std::string session_logout (void * webserver_request);
