@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2018 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/roles.h>
 #include <filter/string.h>
 #include <filter/url.h>
+using namespace std;
 
 
 const char * session_switch_url ()
@@ -42,7 +43,7 @@ bool session_switch_acl (void * webserver_request)
 
 string session_switch (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
 
   string page;
   
@@ -56,7 +57,7 @@ string session_switch (void * webserver_request)
 
   page += view.render ("session", "switch");
 
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
 
   return page;
 }
