@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,15 +17,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_SETUP_INDEX_H
-#define INCLUDED_SETUP_INDEX_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 const char * setup_initialization_notice ();
-string setup_index (void * webserver_request);
-
-
-#endif
+std::string setup_index (void * webserver_request);
