@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,23 +17,17 @@
  */
 
 
-#ifndef INCLUDED_SETUP_LOGIC_H
-#define INCLUDED_SETUP_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
 void setup_conditionally (const char * package);
 void setup_copy_library (const char * package);
 void setup_write_access ();
 void setup_wait_till_main_folders_present ();
 void setup_initialize_data ();
-void setup_set_admin_details (string username, string password, string email);
+void setup_set_admin_details (std::string username, std::string password, std::string email);
 void setup_complete_gui ();
 void setup_generate_locale_databases (bool progress);
 void setup_generate_verse_mapping_databases ();
 void setup_generate_versification_databases ();
-
-
-#endif
