@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include <client/logic.h>
 #include <changes/changes.h>
 #include <email/send.h>
+using namespace std;
 
 
 void statistics_statistics ()
@@ -43,27 +44,30 @@ void statistics_statistics ()
   Database_Logs::log (translate("Sending statistics"), Filter_Roles::manager ());
 
   
-  string siteUrl = config_logic_site_url (NULL);
+  string siteUrl = config::logic::site_url (nullptr);
   
   
   vector <string> bibles = request.database_bibles()->getBibles ();
   
   
-  vector <string> users = request.database_users ()->getUsers ();
+  vector <string> users = request.database_users ()->get_users ();
   for (auto & user : users) {
     
     
     string subject = "Bibledit " + translate("statistics");
-    vector <string> body;
-    
+    stringstream body;
     
+  
+    size_t change_notificatons_count = 0;
     if (request.database_config_user()->getUserPendingChangesNotification (user)) {
-      string any_bible = "";
+      string any_bible = string();
       vector <int> ids = database_modifications.getNotificationIdentifiers (user, any_bible);
-      body.push_back ("<p><a href=\"" + siteUrl + changes_changes_url () + "\">" + translate("Number of change notifications") + "</a>: " + convert_to_string (ids.size()) + "</p>\n");
+      change_notificatons_count = ids.size();
+      body << "<p><a href=" << quoted (siteUrl + changes_changes_url ()) << ">" << translate("Number of change notifications") << "</a>: " << ids.size() << "</p>" << endl;
     }
     
-    
+
+    size_t assigned_notes_count = 0;
     if (request.database_config_user()->getUserAssignedNotesStatisticsNotification (user)) {
       vector <int> ids = database_notes.select_notes (
                                                      bibles, // Bibles.
@@ -81,14 +85,16 @@ void statistics_statistics ()
                                                      0,      // Text selector.
                                                      "",     // Search text.
                                                      -1);     // Limit.
-      body.push_back ("<p><a href=\"" + siteUrl + notes_index_url () + "?presetselection=assigned\">" + translate("Number of consultation notes assigned to you awaiting your response") + "</a>: " + convert_to_string (ids.size ()) + "</p>\n");
+      assigned_notes_count = ids.size();
+      body << "<p><a href=" << quoted (siteUrl + notes_index_url () + "?presetselection=assigned") << ">" << translate("Number of consultation notes assigned to you awaiting your response") << "</a>: " << ids.size() << "</p>" << endl;
     }
     
-    
+
+    size_t subscribed_notes_count = 0;
     if (request.database_config_user()->getUserSubscribedNotesStatisticsNotification (user)) {
-      body.push_back ("<p>" + translate("Number of consultation notes you are subscribed to") + ":</p>\n");
-      body.push_back ("<ul>\n");
-      request.session_logic ()->setUsername (user);
+      body << "<p>" << translate("Number of consultation notes you are subscribed to") << ":</p>" << endl;
+      body << "<ul>" << endl;
+      request.session_logic ()->set_username (user);
       
       vector <int> ids = database_notes.select_notes (
                                                      bibles, // Bible.
@@ -106,7 +112,8 @@ void statistics_statistics ()
                                                      0,      // Text selector.
                                                      "",     // Search text.
                                                      -1);     // Limit.
-      body.push_back ("<li><a href=\"" + siteUrl + notes_index_url () + "?presetselection=subscribed\">" + translate("Total") + "</a>: " + convert_to_string (ids.size ()) + "</li>\n");
+      subscribed_notes_count = ids.size();
+      body << "<li><a href=" << quoted (siteUrl + notes_index_url () + "?presetselection=subscribed") << ">" << translate("Total") << "</a>: " << ids.size () << "</li>" << endl;
       ids = database_notes.select_notes (
                                                      bibles, // Bible.
                                                      0,      // Book
@@ -123,7 +130,7 @@ void statistics_statistics ()
                                                      0,      // Text selector.
                                                      "",     // Search text.
                                                      -1);     // Limit.
-      body.push_back ("<li><a href=\"" + siteUrl + notes_index_url () + "?presetselection=subscribeddayidle\">" + translate("Inactive for a day") + "</a>: " + convert_to_string (ids.size ()) + "</li>\n");
+      body << "<li><a href=" << quoted (siteUrl + notes_index_url () + "?presetselection=subscribeddayidle") << ">" << translate("Inactive for a day") << "</a>: " << ids.size() << "</li>" << endl;
       ids = database_notes.select_notes (
                                                      bibles, // Bible.
                                                      0,      // Book
@@ -140,15 +147,14 @@ void statistics_statistics ()
                                                      0,      // Text selector.
                                                      "",     // Search text.
                                                      -1);     // Limit.
-      body.push_back ("<li><a href=\"" + siteUrl + notes_index_url () + "?presetselection=subscribedweekidle\">" + translate("Inactive for a week") + "</a>: " + convert_to_string (ids.size ()) + "</li>\n");
-      body.push_back ("</ul>\n");
-      request.session_logic ()->setUsername ("");
+      body << "<li><a href=" << quoted (siteUrl + notes_index_url () + "?presetselection=subscribedweekidle") << ">" << translate("Inactive for a week") << "</a>: " << ids.size() << "</li>" << endl;
+      body << "</ul>" << endl;
+      request.session_logic ()->set_username ("");
     }
+
     
-    
-    if (!body.empty ()) {
-      string mailbody = filter_string_implode (body, "\n");
-      email_schedule (user, subject, mailbody);
+    if (change_notificatons_count || assigned_notes_count || subscribed_notes_count) {
+      email_schedule (user, subject, body.str());
     }
   }
 }
