@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2018 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <database/styles.h>
 #include <database/logs.h>
 #include <styles/css.h>
+using namespace std;
 
 
 // Recreates all stylesheet.css files through a background process.
@@ -48,18 +49,18 @@ void Styles_Sheets::recreate ()
 {
   Database_Styles database_styles;
   vector <string> stylesheets = database_styles.getSheets ();
-  for (auto & stylesheet : stylesheets) {
+  for (const auto & stylesheet : stylesheets) {
     string path = get_location (stylesheet, false);
-    create (stylesheet, path, false, "");
+    create (stylesheet, path, false, string());
     path = get_location (stylesheet, true);
-    create (stylesheet, path, true, "");
+    create (stylesheet, path, true, string());
   }
 }
 
 
 void Styles_Sheets::create (string stylesheet, string path, bool editor, string export_bible)
 {
-  Webserver_Request request;
+  Webserver_Request request {};
   Styles_Css styles_css = Styles_Css (&request, stylesheet);
   if (editor) {
     styles_css.editor ();
@@ -67,7 +68,7 @@ void Styles_Sheets::create (string stylesheet, string path, bool editor, string
   if (!export_bible.empty ()) {
     styles_css.exports ();
     styles_css.customize (export_bible);
-    styles_css.customize ("");
+    styles_css.customize (string());
   }
   styles_css.generate ();
   styles_css.css (path);
@@ -81,7 +82,7 @@ string Styles_Sheets::get_location (string sheet, bool editor)
   else path = "basic";
   path.append (sheet);
   path.append (".css");
-  path = filter_url_create_root_path ("dyncss", path);
+  path = filter_url_create_root_path ({"dyncss", path});
   return path;
 }
 
