@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include <access/bible.h>
 #include <bb/logic.h>
 #include <notes/logic.h>
+using namespace std;
 
 
 string sync_notes_url ()
@@ -48,7 +49,7 @@ string sync_notes_url ()
 
 string sync_notes (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Sync_Logic sync_logic = Sync_Logic (webserver_request);
   Database_Notes database_notes (webserver_request);
   Notes_Logic notes_logic = Notes_Logic (webserver_request);
@@ -57,7 +58,7 @@ string sync_notes (void * webserver_request)
   if (!sync_logic.security_okay ()) {
     // When the Cloud enforces https, inform the client to upgrade.
     request->response_code = 426;
-    return "";
+    return string();
   }
 
   
@@ -68,7 +69,7 @@ string sync_notes (void * webserver_request)
   if (!database_notes.available ()) available = false;
   if (!available) {
     request->response_code = 503;
-    return "";
+    return string();
   }
 
 
@@ -82,7 +83,7 @@ string sync_notes (void * webserver_request)
   
   // Check on the credentials when the clients sends data to the server to be stored there.
   if ((action >= Sync_Logic::notes_put_create_initiate) && (action != Sync_Logic::notes_get_bulk)) {
-    if (!sync_logic.credentials_okay ()) return "";
+    if (!sync_logic.credentials_okay ()) return string();
   }
 
 
@@ -91,10 +92,10 @@ string sync_notes (void * webserver_request)
   if ((action == Sync_Logic::notes_get_total) || (action == Sync_Logic::notes_get_identifiers)) {
     if (!request->database_users ()->usernameExists (user)) {
       Database_Logs::log ("A client passes a non-existing user " + user, Filter_Roles::manager ());
-      return "";
+      return string();
     }
   }
-  request->session_logic ()->setUsername (user);
+  request->session_logic ()->set_username (user);
   
   
   // Note lower and upper limits.
@@ -108,7 +109,7 @@ string sync_notes (void * webserver_request)
   switch (action) {
     case Sync_Logic::notes_get_total:
     {
-      vector <string> bibles = access_bible_bibles (webserver_request, user);
+      vector <string> bibles = access_bible::bibles (webserver_request, user);
       vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, bibles, false);
       // Checksum cache to speed things up in case of thousands of notes.
       // Else the server would run at 100% CPU usage for some time to get the total checksums of notes.
@@ -122,14 +123,14 @@ string sync_notes (void * webserver_request)
     }
     case Sync_Logic::notes_get_identifiers:
     {
-      vector <string> bibles = access_bible_bibles (webserver_request, user);
+      vector <string> bibles = access_bible::bibles (webserver_request, user);
       vector <int> identifiers = database_notes.get_notes_in_range_for_bibles (lowId, highId, bibles, false);
       string response;
-      for (auto identifier : identifiers) {
+      for (auto id : identifiers) {
         if (!response.empty ()) response.append ("\n");
-        response.append (convert_to_string (identifier));
+        response.append (convert_to_string (id));
         response.append ("\n");
-        response.append (database_notes.get_checksum (identifier));
+        response.append (database_notes.get_checksum (id));
       }
       return response;
     }
@@ -188,14 +189,14 @@ string sync_notes (void * webserver_request)
       // Update search field.
       database_notes.update_search_fields (identifier);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_create_complete:
     {
       // Do notifications.
       notes_logic.handlerNewNote (identifier);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_summary:
     {
@@ -206,7 +207,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client created or updated a note on the server: " + content, Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_contents:
     {
@@ -215,7 +216,7 @@ string sync_notes (void * webserver_request)
       // Update search field.
       database_notes.update_search_fields (identifier);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_comment:
     {
@@ -228,7 +229,7 @@ string sync_notes (void * webserver_request)
       // Notifications.
       notes_logic.handlerAddComment (identifier);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_subscribe:
     {
@@ -237,7 +238,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client subscribed to note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_unsubscribe:
     {
@@ -246,7 +247,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client unsubscribed from note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_assign:
     {
@@ -257,7 +258,7 @@ string sync_notes (void * webserver_request)
       // Notifications.
       notes_logic.handlerAssignNote (identifier, content);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_unassign:
     {
@@ -266,7 +267,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client unassigned a user from the note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_status:
     {
@@ -275,7 +276,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client set the note status on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_passages:
     {
@@ -283,7 +284,7 @@ string sync_notes (void * webserver_request)
       database_notes.set_raw_passage (identifier, content);
       database_notes.index_raw_passage (identifier, content);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_severity:
     {
@@ -292,14 +293,14 @@ string sync_notes (void * webserver_request)
       // Info
       Database_Logs::log ("Client set the severity for a note on server: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_bible:
     {
       // Set the Bible for a note on the server.
       notes_logic.setBible (identifier, content);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_mark_delete:
     {
@@ -310,7 +311,7 @@ string sync_notes (void * webserver_request)
       // Notifications.
       notes_logic.handlerMarkNoteForDeletion (identifier);
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_unmark_delete:
     {
@@ -319,7 +320,7 @@ string sync_notes (void * webserver_request)
       // Info.
       Database_Logs::log ("Client unmarked a note on server for deletion: " + database_notes.get_summary (identifier), Filter_Roles::manager ());
       // Done.
-      return "";
+      return string();
     }
     case Sync_Logic::notes_put_delete:
     {
@@ -330,7 +331,7 @@ string sync_notes (void * webserver_request)
       // Delete note on server.
       notes_logic.erase (identifier);
       // Done.
-      return "";
+      return string();
     }
     // This method of bulk download was implemented as of September 2016.
     // After a year or so, the logic for the replaced download methods can probably be removed from the Cloud.
@@ -344,11 +345,12 @@ string sync_notes (void * webserver_request)
       string json = database_notes.get_bulk (identifiers);
       return json;
     }
+    default: {};
   }
   
   // Bad request.
   // Delay a while to obstruct a flood of bad requests.
   this_thread::sleep_for (chrono::seconds (1));
   request->response_code = 400;
-  return "";
+  return string();
 }
