@@ -26,6 +26,7 @@
 #include <database/cache.h>
 #include <database/config/general.h>
 #include <tasks/logic.h>
+using namespace std;
 
 
 string sync_resources_url ()
@@ -101,7 +102,7 @@ string sync_resources (void * webserver_request)
         return Database_Cache::path (resource, book);
       }
       
-      default: break;
+      default: {};
     }
   }
     
