@@ -22,5 +22,5 @@
 #include <config/libraries.h>
 #include <filter/string.hpp>
 
-string sync_settings_url ();
-string sync_settings (void * webserver_request);
+std::string sync_settings_url ();
+std::string sync_settings (void * webserver_request);
