@@ -47,6 +47,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <fonts/logic.h>
 #include <manage/index.h>
 #include <client/logic.h>
+using namespace std;
 
 
 string system_index_url ()
@@ -87,7 +88,7 @@ string system_index (void * webserver_request)
   
   // The header: The language has been set already.
   Assets_Header header = Assets_Header (translate("System"), webserver_request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
 
   
@@ -367,6 +368,6 @@ string system_index (void * webserver_request)
 
   
   page += view.render ("system", "index");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
