@@ -23,12 +23,13 @@
 #include <filter/string.h>
 #include <filter/date.h>
 #include <database/logs.h>
+using namespace std;
 
 
 void tmp_tmp ()
 {
   Database_Logs::log ("Removing expired temporal files", Filter_Roles::manager ());
-  int expired = filter_date_seconds_since_epoch () - (3600 * 24 * 3);
+  int expired = filter::date::seconds_since_epoch () - (3600 * 24 * 3);
   string directory = filter_url_create_root_path ({filter_url_temp_dir ()});
   vector <string> names = filter_url_scandir (directory);
   for (auto & name : names) {
