@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2022 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,18 +17,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_USER_LOGIC_H
-#define INCLUDED_USER_LOGIC_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-void user_logic_optional_ldap_authentication (void * webserver_request, string user, string pass);
+void user_logic_optional_ldap_authentication (void * webserver_request, std::string user, std::string pass);
 
 bool user_logic_login_failure_check_okay ();
 void user_logic_login_failure_register ();
 void user_logic_login_failure_clear ();
-
-
-#endif
+void user_logic_store_account_creation (std::string username);
+void user_logic_delete_account (std::string user, std::string role, std::string email, std::string & feedback);
