@@ -27,6 +27,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <filter/url.h>
 #include <filter/date.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #include <mbedtls/entropy.h>
 #include <mbedtls/ctr_drbg.h>
 #include <mbedtls/certs.h>
@@ -37,9 +40,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <mbedtls/net_sockets.h>
 #include <mbedtls/error.h>
 #include <mbedtls/ssl_cache.h>
+#pragma GCC diagnostic pop
 #ifdef HAVE_WINDOWS
 #include <io.h>
 #endif
+using namespace std;
 
 
 // Internal function declarations.
@@ -278,18 +283,18 @@ void http_server ()
   memset (&serveraddr, 0, sizeof (serveraddr));
   serveraddr.sin_family = AF_INET;
   serveraddr.sin_addr.s_addr = htonl (INADDR_LOOPBACK);
-  serveraddr.sin_port = htons (convert_to_int (config_logic_http_network_port ()));
+  serveraddr.sin_port = htons (convert_to_int (config::logic::http_network_port ()));
 #endif
 #ifdef HAVE_CLOUD
   // When configured as a server it listens on any IPv6 address.
-  struct sockaddr_in6 serveraddr;
+  sockaddr_in6 serveraddr;
   memset (&serveraddr, 0, sizeof (serveraddr));
   serveraddr.sin6_flowinfo = 0;
   serveraddr.sin6_family = AF_INET6;
   serveraddr.sin6_addr = in6addr_any;
-  serveraddr.sin6_port = htons (static_cast<uint16_t>(convert_to_int (config_logic_http_network_port ())));
+  serveraddr.sin6_port = htons (static_cast<uint16_t>(convert_to_int (config::logic::http_network_port ())));
 #endif
-  result = mybind (listenfd, reinterpret_cast<struct sockaddr *>(&serveraddr), sizeof (serveraddr));
+  result = mybind (listenfd, reinterpret_cast<sockaddr *>(&serveraddr), sizeof (serveraddr));
   if (result != 0) {
     string error = "Error binding server to socket: ";
     error.append (strerror (errno));
@@ -313,13 +318,13 @@ void http_server ()
   while (listener_healthy && config_globals_webserver_running) {
 
     // Socket and file descriptor for the client connection.
-    struct sockaddr_in6 clientaddr6;
+    sockaddr_in6 clientaddr6;
     socklen_t clientlen = sizeof (clientaddr6);
-    int connfd = accept (listenfd, reinterpret_cast<struct sockaddr *>(&clientaddr6), &clientlen);
+    int connfd = accept (listenfd, reinterpret_cast<sockaddr *>(&clientaddr6), &clientlen);
     if (connfd > 0) {
 
       // Socket receive timeout, plain http.
-      struct timeval tv;
+      timeval tv;
       tv.tv_sec = 60;
       tv.tv_usec = 0;
       setsockopt (connfd, SOL_SOCKET, SO_RCVTIMEO, &tv, sizeof(tv));
@@ -432,7 +437,7 @@ void http_server ()
   memset(&serveraddr, 0, sizeof(serveraddr));
   serveraddr.sin_family = AF_INET;
   serveraddr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-  serveraddr.sin_port = htons(convert_to_int(config_logic_http_network_port()));
+  serveraddr.sin_port = htons(convert_to_int(config::logic::http_network_port()));
   result = mybind(listen_socket, (SA *)&serveraddr, sizeof(serveraddr));
   if (result == SOCKET_ERROR) {
 	  string error = "Error binding server to socket";
@@ -483,7 +488,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
 {
   // Socket receive timeout, secure https.
 #ifndef HAVE_WINDOWS
-  struct timeval tv;
+  timeval tv;
   tv.tv_sec = 60;
   tv.tv_usec = 0;
   setsockopt (client_fd.fd, SOL_SOCKET, SO_RCVTIMEO, &tv, sizeof(tv));
@@ -506,9 +511,9 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
     if (config_globals_webserver_running) {
 
       // Get client's remote IPv4 address in dotted notation and put it in the webserver request object.
-      struct sockaddr_in addr;
-      socklen_t addr_size = sizeof(struct sockaddr_in);
-      getpeername (client_fd.fd, reinterpret_cast<struct sockaddr *>(&addr), &addr_size);
+      sockaddr_in addr;
+      socklen_t addr_size = sizeof(sockaddr_in);
+      getpeername (client_fd.fd, reinterpret_cast<sockaddr *>(&addr), &addr_size);
       char remote_address [256];
       inet_ntop (AF_INET, &addr.sin_addr.s_addr, remote_address, sizeof (remote_address));
       request.remote_address = remote_address;
@@ -521,13 +526,13 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
       if (connection_healthy) {
         ret = mbedtls_ssl_setup (&ssl, conf);
         if (ret != 0) {
-          filter_url_display_mbed_tls_error (ret, NULL, true);
+          filter_url_display_mbed_tls_error (ret, nullptr, true);
           connection_healthy = false;
         }
       }
       
       if (connection_healthy) {
-        mbedtls_ssl_set_bio (&ssl, &client_fd, mbedtls_net_send, mbedtls_net_recv, NULL);
+        mbedtls_ssl_set_bio (&ssl, &client_fd, mbedtls_net_send, mbedtls_net_recv, nullptr);
       }
       
       // SSL / TLS handshake.
@@ -536,7 +541,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           if (config_globals_webserver_running) {
             // In case the secure server runs, display the error.
             // And in case the server is interrupted by e.g. Ctrl-C, don't display this error.
-            filter_url_display_mbed_tls_error (ret, NULL, true);
+            filter_url_display_mbed_tls_error (ret, nullptr, true);
           }
           connection_healthy = false;
         }
@@ -638,7 +643,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           // until it returns a positive value.
           if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
           if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
-          filter_url_display_mbed_tls_error (ret, NULL, true);
+          filter_url_display_mbed_tls_error (ret, nullptr, true);
           connection_healthy = false;
         }
       }
@@ -684,7 +689,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
               // until it returns a positive value.
               if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
               if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
-              filter_url_display_mbed_tls_error (ret, NULL, true);
+              filter_url_display_mbed_tls_error (ret, nullptr, true);
               connection_healthy = false;
             }
           }
@@ -703,7 +708,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         while ((ret = mbedtls_ssl_close_notify (&ssl)) < 0) {
           if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
           if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
-          filter_url_display_mbed_tls_error (ret, NULL, true);
+          filter_url_display_mbed_tls_error (ret, nullptr, true);
           connection_healthy = false;
           if (connection_healthy) {}; // Suppress static analyzer warning about unused code.
           break;
@@ -739,10 +744,46 @@ void https_server ()
 #ifdef RUN_SECURE_SERVER
 
   // The https network port to listen on.
-  // Port "0..9" means: Don't run the secure web server.
-  string network_port = config_logic_https_network_port ();
+  // Port 0..9 means this:: Don't run the secure web server.
+  string network_port = config::logic::https_network_port ();
   if (network_port.length() <= 1) return;
   
+  // Check whether all the certificates are there and can be read.
+  // If not, log some feedback and don't run the secure web server.
+  string server_key_path {config::logic::server_key_path (false)};
+  string server_certificate_path {config::logic::server_certificate_path (false)};
+  string authorities_certificates_path {config::logic::authorities_certificates_path (false)};
+  if (!server_key_path.empty()) {
+    string contents {filter_url_file_get_contents (server_key_path)};
+    if (contents.empty()) {
+      Database_Logs::log("Cannot read " + server_key_path + " so not running secure server");
+      return;
+    }
+  } else {
+    Database_Logs::log("Cannot find server private key in " + config::logic::server_key_path (true) + " so not running secure server");
+    return;
+  }
+  if (!server_certificate_path.empty()) {
+    string contents {filter_url_file_get_contents (server_certificate_path)};
+    if (contents.empty()) {
+      Database_Logs::log("Cannot read " + server_certificate_path + " so not running secure server");
+      return;
+    }
+  } else {
+    Database_Logs::log("Cannot find server certificate in " + config::logic::server_certificate_path (true) + " so not running secure server");
+    return;
+  }
+  if (!authorities_certificates_path.empty()) {
+    string contents {filter_url_file_get_contents (authorities_certificates_path)};
+    if (contents.empty()) {
+      Database_Logs::log("Cannot read " + authorities_certificates_path + " so not running secure server");
+      return;
+    }
+  } else {
+    Database_Logs::log("Cannot find certificate authorities chain in " + config::logic::authorities_certificates_path (true) + " so not running secure server");
+    return;
+  }
+  
   // File descriptor for the listener.
   mbedtls_net_context listen_fd;
   mbedtls_net_init (&listen_fd);
@@ -762,59 +803,67 @@ void https_server ()
   mbedtls_ctr_drbg_context ctr_drbg;
   mbedtls_ctr_drbg_init (&ctr_drbg);
 
-  int ret;
-  string path;
-  
   // Load the private RSA server key.
   mbedtls_pk_context pkey;
   mbedtls_pk_init (&pkey);
-  path = config_logic_server_key_path ();
-  ret = mbedtls_pk_parse_keyfile (&pkey, path.c_str (), NULL);
-  if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
+  int ret = mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr);
+  if (ret != 0) {
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
+    Database_Logs::log("Invalid " + server_key_path + " so not running secure server");
+    return;
+  }
   
   // Server certificates store.
   mbedtls_x509_crt srvcert;
   mbedtls_x509_crt_init (&srvcert);
   
   // Load the server certificate.
-  path = config_logic_server_certificate_path ();
-  ret = mbedtls_x509_crt_parse_file (&srvcert, path.c_str ());
-  if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
+  ret = mbedtls_x509_crt_parse_file (&srvcert, server_certificate_path.c_str ());
+  if (ret != 0) {
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
+    Database_Logs::log("Invalid " + server_certificate_path + " so not running secure server");
+    return;
+  }
 
   // Load the chain of certificates of the certificate authorities.
-  path = config_logic_authorities_certificates_path ();
-  ret = mbedtls_x509_crt_parse_file (&srvcert, path.c_str ());
-  if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
+  ret = mbedtls_x509_crt_parse_file (&srvcert, authorities_certificates_path.c_str ());
+  if (ret != 0) {
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
+    Database_Logs::log("Invalid " + authorities_certificates_path + " so not running secure server");
+    return;
+  }
 
   // Seed the random number generator.
   const char *pers = "Cloud";
   ret = mbedtls_ctr_drbg_seed( &ctr_drbg, mbedtls_entropy_func, &entropy, reinterpret_cast<const unsigned char *> (pers), strlen (pers));
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
     return;
   }
   
   // Setup the listening TCP socket.
-  ret = mbedtls_net_bind (&listen_fd, NULL, network_port.c_str (), MBEDTLS_NET_PROTO_TCP);
+  ret = mbedtls_net_bind (&listen_fd, nullptr, network_port.c_str (), MBEDTLS_NET_PROTO_TCP);
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
     return;
   }
   
   // Setup SSL/TLS default values for the lifetime of the https server.
   ret = mbedtls_ssl_config_defaults (&conf, MBEDTLS_SSL_IS_SERVER, MBEDTLS_SSL_TRANSPORT_STREAM, MBEDTLS_SSL_PRESET_DEFAULT);
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
     return;
   }
   mbedtls_ssl_conf_rng (&conf, mbedtls_ctr_drbg_random, &ctr_drbg);
   mbedtls_ssl_conf_session_cache (&conf, &cache, mbedtls_ssl_cache_get, mbedtls_ssl_cache_set);
-  mbedtls_ssl_conf_ca_chain (&conf, srvcert.next, NULL);
+  mbedtls_ssl_conf_ca_chain (&conf, srvcert.next, nullptr);
   ret = mbedtls_ssl_conf_own_cert (&conf, &srvcert, &pkey);
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true);
     return;
   }
+
+  cout << "Listening on https://localhost:" << network_port << endl;
   
   // Keep preparing for, accepting, and processing client connections.
   while (config_globals_webserver_running) {
@@ -824,9 +873,9 @@ void https_server ()
     mbedtls_net_init (&client_fd);
     
     // Wait until a client connects.
-    ret = mbedtls_net_accept (&listen_fd, &client_fd, NULL, 0, NULL);
+    ret = mbedtls_net_accept (&listen_fd, &client_fd, nullptr, 0, nullptr);
     if (ret != 0 ) {
-      filter_url_display_mbed_tls_error (ret, NULL, true);
+      filter_url_display_mbed_tls_error (ret, nullptr, true);
       continue;
     }
     
