@@ -35,6 +35,7 @@
 #include <database/logs.h>
 #include <database/cache.h>
 #include <read/index.h>
+using namespace std;
 
 
 vector <string> workspace_get_default_names ()
@@ -42,7 +43,7 @@ vector <string> workspace_get_default_names ()
   // Any of the names below should not contain commas,
   // because the sorting mechanism takes the comma as a separator,
   // so if commas are in a name, the sorting no longer works.
-  if (config_logic_indonesian_cloud_free_simple ()) {
+  if (config::logic::indonesian_cloud_free_simple ()) {
     return {
       "Baca dan Teliti"
     };
@@ -59,7 +60,7 @@ vector <string> workspace_get_default_names ()
 
 map <int, string> workspace_get_default_urls (int id)
 {
-  map <int, string> urls;
+  map <int, string> urls {};
   switch (id) {
     case 1:
       urls [0] = editone2_index_url ();
@@ -90,7 +91,7 @@ map <int, string> workspace_get_default_urls (int id)
       urls [3] = search_index_url ();
       break;
   }
-  if (config_logic_indonesian_cloud_free_simple ()) {
+  if (config::logic::indonesian_cloud_free_simple ()) {
     urls [0] = read_index_url ();
     urls [1] = resource_index_url ();
     urls [2] = "";
@@ -134,7 +135,7 @@ map <int, string> workspace_get_default_widths (int id)
       widths [3] = "1";
       break;
   }
-  if (config_logic_indonesian_cloud_free_simple ()) {
+  if (config::logic::indonesian_cloud_free_simple ()) {
     widths [0] = "1";
     widths [1] = "1";
     widths [2] = "0";
@@ -166,7 +167,7 @@ map <int, string> workspace_get_default_heights (int id)
       heights [0] = "1";
       break;
   }
-  if (config_logic_indonesian_cloud_free_simple ()) {
+  if (config::logic::indonesian_cloud_free_simple ()) {
     heights [0] = "1";
     heights [1] = "0";
   }
@@ -185,7 +186,7 @@ void workspace_create_defaults (void * webserver_request)
   vector <string> names = workspace_get_default_names ();
   for (unsigned int i = 0; i < names.size (); i++) {
     request->database_config_user()->setActiveWorkspace (names [i]);
-    int bench = i + 1;
+    int bench = static_cast<int>(i + 1);
     workspace_set_urls (request, workspace_get_default_urls (bench));
     workspace_set_widths (request, workspace_get_default_widths (bench));
     workspace_set_heights (request, workspace_get_default_heights (bench));
@@ -215,10 +216,8 @@ string workspace_process_units (string length)
   // If a size factor is found, great, otherwise default to 1
   if (length == convert_to_string (convert_to_int (length))) {
     return length;
-  } else {
-    string length = "1";
-    return length;
   }
+  return "1";
 }
 
 
@@ -571,7 +570,7 @@ void workspace_send (void * webserver_request, string workspace, string user)
 
   // New webserver request object for the destination user.
   Webserver_Request destination_request;
-  destination_request.session_logic ()->setUsername (user);
+  destination_request.session_logic ()->set_username (user);
   
   // Save workspace for destination user.
   active_workspace = destination_request.database_config_user()->getActiveWorkspace ();
