@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2022 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <dialog/yes.h>
 #include <dialog/entry.h>
 #include <menu/logic.h>
+using namespace std;
 
 
 string workspace_organize_url ()
@@ -46,7 +47,7 @@ bool workspace_organize_acl (void * webserver_request)
 
 string workspace_organize (void * webserver_request)
 {
-  Webserver_Request * request = (Webserver_Request *) webserver_request;
+  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   
   
   string success;
@@ -65,14 +66,14 @@ string workspace_organize (void * webserver_request)
   
   // Re-ordering workspaces.
   if (request->query.count ("up")) {
-    size_t item = convert_to_int (request->query ["up"]);
+    size_t item = static_cast<size_t>(convert_to_int (request->query ["up"]));
     vector <string> workspaces = workspace_get_names (request);
     array_move_up_down (workspaces, item, true);
     workspace_reorder (request, workspaces);
     success = translate ("The workspace was moved up");
   }
   if (request->query.count ("down")) {
-    size_t item = convert_to_int (request->query ["down"]);
+    size_t item = static_cast<size_t>(convert_to_int (request->query ["down"]));
     vector <string> workspaces = workspace_get_names (request);
     array_move_up_down (workspaces, item, false);
     workspace_reorder (request, workspaces);
@@ -91,7 +92,7 @@ string workspace_organize (void * webserver_request)
   
   
   Assets_Header header = Assets_Header (translate("Workspaces"), request);
-  header.addBreadCrumb (menu_logic_settings_menu (), menu_logic_settings_text ());
+  header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   
   
@@ -131,7 +132,7 @@ string workspace_organize (void * webserver_request)
   string send = request->query ["send"];
   if (!send.empty ()) {
     string me = request->session_logic ()->currentUser ();
-    vector <string> users = request->database_users ()->getUsers ();
+    vector <string> users = request->database_users ()->get_users ();
     for (auto user : users) {
       if (user != me) {
         workspace_send (webserver_request, send, user);
@@ -144,31 +145,31 @@ string workspace_organize (void * webserver_request)
   Assets_View view;
   
   
-  vector <string> workspaceblock;
+  stringstream workspaceblock;
   vector <string> workspaces = workspace_get_names (request, false);
   for (size_t i = 0; i < workspaces.size (); i++) {
     string workspace = workspaces [i];
-    workspaceblock.push_back ("<p>");
-    workspaceblock.push_back ("<a href=\"?remove=" + workspace + "\" title=\"" + translate("Delete workspace") + "\">" + emoji_wastebasket () + "</a>");
-    workspaceblock.push_back ("|");
-    workspaceblock.push_back ("<a href=\"?up=" + convert_to_string (i) + "\" title=\"" + translate("Move workspace up") + "\"> " + unicode_black_up_pointing_triangle () + " </a>");
-    workspaceblock.push_back ("|");
-    workspaceblock.push_back ("<a href=\"?down=" + convert_to_string (i) + "\" title=\"" + translate("Move workspace down") + "\"> " + unicode_black_down_pointing_triangle () + " </a>");
-    workspaceblock.push_back ("|");
-    workspaceblock.push_back ("<a href=\"settings?name=" + workspace + "\" title=\"" + translate("Edit workspace") + "\"> ✎ </a>");
-    workspaceblock.push_back ("|");
-    workspaceblock.push_back ("<a href=\"?copy=" + workspace + "\" title=\"" + translate("Copy workspace") + "\"> ⎘ </a>");
+    workspaceblock << "<p>" << endl;
+    workspaceblock << "<a href=" << quoted ("?remove=" + workspace) << " title=" << quoted (translate("Delete workspace")) << ">" << emoji_wastebasket () << "</a>" << endl;
+    workspaceblock << "|" << endl;
+    workspaceblock << "<a href=" << quoted ("?up=" + convert_to_string (i)) << " title=" << quoted (translate("Move workspace up")) << "> " << unicode_black_up_pointing_triangle () << " </a>" << endl;
+    workspaceblock << "|" << endl;
+    workspaceblock << "<a href=" << quoted ("?down=" + convert_to_string (i)) << " title=" << quoted (translate("Move workspace down")) << "> " << unicode_black_down_pointing_triangle () << " </a>" << endl;
+    workspaceblock << "|" << endl;
+    workspaceblock << "<a href=" << quoted ("settings?name=" + workspace) << " title=" << quoted (translate("Edit workspace")) << "> ✎ </a>" << endl;
+    workspaceblock << "|";
+    workspaceblock << "<a href=" << quoted ("?copy=" + workspace) << " title=" << quoted (translate("Copy workspace")) << "> ⎘ </a>" << endl;
 #ifndef HAVE_CLIENT
     // In the Cloud, one can send the workspace configuration to other users.
     // On a client, sending a workspace to other users does not work.
-    workspaceblock.push_back ("|");
-    workspaceblock.push_back ("<a href=\"?send=" + workspace + "\" title=\"" + translate("Send workspace to all users") + "\"> ✉ </a>");
+    workspaceblock << "|" << endl;
+    workspaceblock << "<a href=" << quoted ("?send=" + workspace) << " title=" << quoted (translate("Send workspace to all users")) << "> ✉ </a>" << endl;
 #endif
-    workspaceblock.push_back ("|");
-    workspaceblock.push_back ("<span>" + workspace + "</span>");
-    workspaceblock.push_back ("</p>");
+    workspaceblock << "|" << endl;
+    workspaceblock << "<span>" << workspace << "</span>" << endl;
+    workspaceblock << "</p>" << endl;
   }
-  view.set_variable ("workspaceblock", filter_string_implode (workspaceblock, "\n"));
+  view.set_variable ("workspaceblock", workspaceblock.str());
 
   
 #ifndef HAVE_CLIENT
@@ -183,7 +184,7 @@ string workspace_organize (void * webserver_request)
   page += view.render ("workspace", "organize");
   
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   
   return page;
